/* aarch64-system-regs.def -- AArch64 opcode support.
   Copyright (C) 2009-2026 Free Software Foundation, Inc.
   Contributed by ARM Ltd.

   This file is part of the GNU opcodes library.

   This library is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   It is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING3.  If not,
   see <http://www.gnu.org/licenses/>.  */

/* Array of system registers and their associated arch features.

   This file is also used by GCC.  Where necessary, any updates should
   be made in Binutils and the updated file copied across to GCC, such
   that the two projects are kept in sync at all times.

   Before using #include to read this file, define a macro:

     SYSREG (name, encoding, flags, features)

  The NAME is the system register name, as recognized by the
  assembler.  ENCODING provides the necessary information for the binary
  encoding of the system register.  The FLAGS field is a bitmask of
  relevant behavior information pertaining to the particular register.
  For example: is it read/write-only? does it alias another register?
  The FEATURES field maps onto ISA flags and specifies the architectural
  feature requirements of the system register.  */

  SYSREG ("accdata_el1",	CPENC (3,0,13,0,5),	0,		AARCH64_FEATURE (LS64)) /* LS64_ACCDATA */
  SYSREG ("actlr_el1",		CPENC (3,0,1,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("actlr_el12",		CPENC (3,5,1,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("actlr_el2",		CPENC (3,4,1,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("actlr_el3",		CPENC (3,6,1,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("actlralias_el1",	CPENC (3,0,1,4,5),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("actlrmask_el1",	CPENC (3,0,1,4,1),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("actlrmask_el12",	CPENC (3,5,1,4,1),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("actlrmask_el2",	CPENC (3,4,1,4,1),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("afgdtp0_el1",	CPENC (3,0,3,6,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp0_el12",	CPENC (3,5,3,6,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp0_el2",	CPENC (3,4,3,6,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp0_el3",	CPENC (3,6,3,6,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp10_el1",	CPENC (3,0,3,7,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp10_el12",	CPENC (3,5,3,7,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp10_el2",	CPENC (3,4,3,7,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp10_el3",	CPENC (3,6,3,7,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp11_el1",	CPENC (3,0,3,7,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp11_el12",	CPENC (3,5,3,7,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp11_el2",	CPENC (3,4,3,7,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp11_el3",	CPENC (3,6,3,7,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp12_el1",	CPENC (3,0,3,7,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp12_el12",	CPENC (3,5,3,7,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp12_el2",	CPENC (3,4,3,7,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp12_el3",	CPENC (3,6,3,7,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp13_el1",	CPENC (3,0,3,7,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp13_el12",	CPENC (3,5,3,7,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp13_el2",	CPENC (3,4,3,7,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp13_el3",	CPENC (3,6,3,7,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp14_el1",	CPENC (3,0,3,7,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp14_el12",	CPENC (3,5,3,7,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp14_el2",	CPENC (3,4,3,7,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp14_el3",	CPENC (3,6,3,7,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp15_el1",	CPENC (3,0,3,7,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp15_el12",	CPENC (3,5,3,7,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp15_el2",	CPENC (3,4,3,7,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp15_el3",	CPENC (3,6,3,7,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp1_el1",	CPENC (3,0,3,6,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp1_el12",	CPENC (3,5,3,6,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp1_el2",	CPENC (3,4,3,6,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp1_el3",	CPENC (3,6,3,6,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp2_el1",	CPENC (3,0,3,6,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp2_el12",	CPENC (3,5,3,6,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp2_el2",	CPENC (3,4,3,6,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp2_el3",	CPENC (3,6,3,6,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp3_el1",	CPENC (3,0,3,6,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp3_el12",	CPENC (3,5,3,6,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp3_el2",	CPENC (3,4,3,6,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp3_el3",	CPENC (3,6,3,6,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp4_el1",	CPENC (3,0,3,6,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp4_el12",	CPENC (3,5,3,6,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp4_el2",	CPENC (3,4,3,6,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp4_el3",	CPENC (3,6,3,6,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp5_el1",	CPENC (3,0,3,6,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp5_el12",	CPENC (3,5,3,6,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp5_el2",	CPENC (3,4,3,6,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp5_el3",	CPENC (3,6,3,6,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp6_el1",	CPENC (3,0,3,6,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp6_el12",	CPENC (3,5,3,6,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp6_el2",	CPENC (3,4,3,6,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp6_el3",	CPENC (3,6,3,6,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp7_el1",	CPENC (3,0,3,6,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp7_el12",	CPENC (3,5,3,6,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp7_el2",	CPENC (3,4,3,6,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp7_el3",	CPENC (3,6,3,6,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp8_el1",	CPENC (3,0,3,7,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp8_el12",	CPENC (3,5,3,7,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp8_el2",	CPENC (3,4,3,7,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp8_el3",	CPENC (3,6,3,7,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp9_el1",	CPENC (3,0,3,7,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp9_el12",	CPENC (3,5,3,7,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp9_el2",	CPENC (3,4,3,7,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtp9_el3",	CPENC (3,6,3,7,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu0_el1",	CPENC (3,0,3,8,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu0_el12",	CPENC (3,5,3,8,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu0_el2",	CPENC (3,4,3,8,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu10_el1",	CPENC (3,0,3,9,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu10_el12",	CPENC (3,5,3,9,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu10_el2",	CPENC (3,4,3,9,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu11_el1",	CPENC (3,0,3,9,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu11_el12",	CPENC (3,5,3,9,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu11_el2",	CPENC (3,4,3,9,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu12_el1",	CPENC (3,0,3,9,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu12_el12",	CPENC (3,5,3,9,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu12_el2",	CPENC (3,4,3,9,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu13_el1",	CPENC (3,0,3,9,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu13_el12",	CPENC (3,5,3,9,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu13_el2",	CPENC (3,4,3,9,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu14_el1",	CPENC (3,0,3,9,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu14_el12",	CPENC (3,5,3,9,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu14_el2",	CPENC (3,4,3,9,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu15_el1",	CPENC (3,0,3,9,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu15_el12",	CPENC (3,5,3,9,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu15_el2",	CPENC (3,4,3,9,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu1_el1",	CPENC (3,0,3,8,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu1_el12",	CPENC (3,5,3,8,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu1_el2",	CPENC (3,4,3,8,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu2_el1",	CPENC (3,0,3,8,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu2_el12",	CPENC (3,5,3,8,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu2_el2",	CPENC (3,4,3,8,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu3_el1",	CPENC (3,0,3,8,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu3_el12",	CPENC (3,5,3,8,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu3_el2",	CPENC (3,4,3,8,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu4_el1",	CPENC (3,0,3,8,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu4_el12",	CPENC (3,5,3,8,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu4_el2",	CPENC (3,4,3,8,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu5_el1",	CPENC (3,0,3,8,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu5_el12",	CPENC (3,5,3,8,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu5_el2",	CPENC (3,4,3,8,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu6_el1",	CPENC (3,0,3,8,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu6_el12",	CPENC (3,5,3,8,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu6_el2",	CPENC (3,4,3,8,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu7_el1",	CPENC (3,0,3,8,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu7_el12",	CPENC (3,5,3,8,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu7_el2",	CPENC (3,4,3,8,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu8_el1",	CPENC (3,0,3,9,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu8_el12",	CPENC (3,5,3,9,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu8_el2",	CPENC (3,4,3,9,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu9_el1",	CPENC (3,0,3,9,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu9_el12",	CPENC (3,5,3,9,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afgdtu9_el2",	CPENC (3,4,3,9,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("afsr0_el1",		CPENC (3,0,5,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("afsr0_el12",		CPENC (3,5,5,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("afsr0_el2",		CPENC (3,4,5,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("afsr0_el3",		CPENC (3,6,5,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("afsr1_el1",		CPENC (3,0,5,1,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("afsr1_el12",		CPENC (3,5,5,1,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("afsr1_el2",		CPENC (3,4,5,1,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("afsr1_el3",		CPENC (3,6,5,1,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("aidr_el1",		CPENC (3,1,0,0,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("allint",		CPENC (3,0,4,3,0),	0,		AARCH64_FEATURE (V8_7A)) /* NMI */
  SYSREG ("amair_el1",		CPENC (3,0,10,3,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("amair_el12",		CPENC (3,5,10,3,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("amair_el2",		CPENC (3,4,10,3,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("amair_el3",		CPENC (3,6,10,3,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("amair2_el1",		CPENC (3,0,10,3,1),	0,		AARCH64_FEATURE (V8_8A)) /* AIE */
  SYSREG ("amair2_el12",	CPENC (3,5,10,3,1),	0,		AARCH64_FEATURE (V8_8A)) /* AIE */
  SYSREG ("amair2_el2",		CPENC (3,4,10,3,1),	0,		AARCH64_FEATURE (V8_8A)) /* AIE */
  SYSREG ("amair2_el3",		CPENC (3,6,10,3,1),	0,		AARCH64_FEATURE (V8_8A)) /* AIE */
  SYSREG ("amcfgr_el0",		CPENC (3,3,13,2,1),	F_REG_READ,	AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amcg1idr_el0",	CPENC (3,3,13,2,6),	F_REG_READ,	AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amcgcr_el0",		CPENC (3,3,13,2,2),	F_REG_READ,	AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amcntenclr0_el0",	CPENC (3,3,13,2,4),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amcntenclr1_el0",	CPENC (3,3,13,3,0),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amcntenset0_el0",	CPENC (3,3,13,2,5),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amcntenset1_el0",	CPENC (3,3,13,3,1),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amcr_el0",		CPENC (3,3,13,2,0),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr00_el0",	CPENC (3,3,13,4,0),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr01_el0",	CPENC (3,3,13,4,1),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr02_el0",	CPENC (3,3,13,4,2),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr03_el0",	CPENC (3,3,13,4,3),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr10_el0",	CPENC (3,3,13,12,0),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr110_el0",	CPENC (3,3,13,13,2),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr111_el0",	CPENC (3,3,13,13,3),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr112_el0",	CPENC (3,3,13,13,4),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr113_el0",	CPENC (3,3,13,13,5),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr114_el0",	CPENC (3,3,13,13,6),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr115_el0",	CPENC (3,3,13,13,7),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr11_el0",	CPENC (3,3,13,12,1),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr12_el0",	CPENC (3,3,13,12,2),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr13_el0",	CPENC (3,3,13,12,3),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr14_el0",	CPENC (3,3,13,12,4),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr15_el0",	CPENC (3,3,13,12,5),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr16_el0",	CPENC (3,3,13,12,6),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr17_el0",	CPENC (3,3,13,12,7),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr18_el0",	CPENC (3,3,13,13,0),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntr19_el0",	CPENC (3,3,13,13,1),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevcntvoff00_el2",	CPENC (3,4,13,8,0),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff010_el2",	CPENC (3,4,13,9,2),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff011_el2",	CPENC (3,4,13,9,3),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff012_el2",	CPENC (3,4,13,9,4),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff013_el2",	CPENC (3,4,13,9,5),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff014_el2",	CPENC (3,4,13,9,6),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff015_el2",	CPENC (3,4,13,9,7),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff01_el2",	CPENC (3,4,13,8,1),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff02_el2",	CPENC (3,4,13,8,2),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff03_el2",	CPENC (3,4,13,8,3),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff04_el2",	CPENC (3,4,13,8,4),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff05_el2",	CPENC (3,4,13,8,5),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff06_el2",	CPENC (3,4,13,8,6),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff07_el2",	CPENC (3,4,13,8,7),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff08_el2",	CPENC (3,4,13,9,0),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff09_el2",	CPENC (3,4,13,9,1),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff10_el2",	CPENC (3,4,13,10,0),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff110_el2",	CPENC (3,4,13,11,2),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff111_el2",	CPENC (3,4,13,11,3),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff112_el2",	CPENC (3,4,13,11,4),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff113_el2",	CPENC (3,4,13,11,5),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff114_el2",	CPENC (3,4,13,11,6),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff115_el2",	CPENC (3,4,13,11,7),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff11_el2",	CPENC (3,4,13,10,1),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff12_el2",	CPENC (3,4,13,10,2),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff13_el2",	CPENC (3,4,13,10,3),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff14_el2",	CPENC (3,4,13,10,4),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff15_el2",	CPENC (3,4,13,10,5),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff16_el2",	CPENC (3,4,13,10,6),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff17_el2",	CPENC (3,4,13,10,7),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff18_el2",	CPENC (3,4,13,11,0),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevcntvoff19_el2",	CPENC (3,4,13,11,1),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1p1 */
  SYSREG ("amevtyper00_el0",	CPENC (3,3,13,6,0),	F_REG_READ,	AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper01_el0",	CPENC (3,3,13,6,1),	F_REG_READ,	AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper02_el0",	CPENC (3,3,13,6,2),	F_REG_READ,	AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper03_el0",	CPENC (3,3,13,6,3),	F_REG_READ,	AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper10_el0",	CPENC (3,3,13,14,0),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper110_el0",	CPENC (3,3,13,15,2),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper111_el0",	CPENC (3,3,13,15,3),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper112_el0",	CPENC (3,3,13,15,4),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper113_el0",	CPENC (3,3,13,15,5),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper114_el0",	CPENC (3,3,13,15,6),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper115_el0",	CPENC (3,3,13,15,7),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper11_el0",	CPENC (3,3,13,14,1),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper12_el0",	CPENC (3,3,13,14,2),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper13_el0",	CPENC (3,3,13,14,3),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper14_el0",	CPENC (3,3,13,14,4),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper15_el0",	CPENC (3,3,13,14,5),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper16_el0",	CPENC (3,3,13,14,6),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper17_el0",	CPENC (3,3,13,14,7),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper18_el0",	CPENC (3,3,13,15,0),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amevtyper19_el0",	CPENC (3,3,13,15,1),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("amuserenr_el0",	CPENC (3,3,13,2,3),	0,		AARCH64_FEATURE (V8_3A)) /* AMUv1 */
  SYSREG ("apdakeyhi_el1",	CPENC (3,0,2,2,1),	0,		AARCH64_FEATURE (PAUTH))
  SYSREG ("apdakeylo_el1",	CPENC (3,0,2,2,0),	0,		AARCH64_FEATURE (PAUTH))
  SYSREG ("apdbkeyhi_el1",	CPENC (3,0,2,2,3),	0,		AARCH64_FEATURE (PAUTH))
  SYSREG ("apdbkeylo_el1",	CPENC (3,0,2,2,2),	0,		AARCH64_FEATURE (PAUTH))
  SYSREG ("apgakeyhi_el1",	CPENC (3,0,2,3,1),	0,		AARCH64_FEATURE (PAUTH))
  SYSREG ("apgakeylo_el1",	CPENC (3,0,2,3,0),	0,		AARCH64_FEATURE (PAUTH))
  SYSREG ("apiakeyhi_el1",	CPENC (3,0,2,1,1),	0,		AARCH64_FEATURE (PAUTH))
  SYSREG ("apiakeylo_el1",	CPENC (3,0,2,1,0),	0,		AARCH64_FEATURE (PAUTH))
  SYSREG ("apibkeyhi_el1",	CPENC (3,0,2,1,3),	0,		AARCH64_FEATURE (PAUTH))
  SYSREG ("apibkeylo_el1",	CPENC (3,0,2,1,2),	0,		AARCH64_FEATURE (PAUTH))
  SYSREG ("brbcr_el1",		CPENC (2,1,9,0,0),	0,		AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbcr_el12",		CPENC (2,5,9,0,0),	0,		AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbcr_el2",		CPENC (2,4,9,0,0),	0,		AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbfcr_el1",		CPENC (2,1,9,0,1),	0,		AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbidr0_el1",	CPENC (2,1,9,2,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf0_el1",	CPENC (2,1,8,0,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf10_el1",	CPENC (2,1,8,10,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf11_el1",	CPENC (2,1,8,11,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf12_el1",	CPENC (2,1,8,12,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf13_el1",	CPENC (2,1,8,13,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf14_el1",	CPENC (2,1,8,14,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf15_el1",	CPENC (2,1,8,15,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf16_el1",	CPENC (2,1,8,0,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf17_el1",	CPENC (2,1,8,1,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf18_el1",	CPENC (2,1,8,2,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf19_el1",	CPENC (2,1,8,3,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf1_el1",	CPENC (2,1,8,1,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf20_el1",	CPENC (2,1,8,4,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf21_el1",	CPENC (2,1,8,5,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf22_el1",	CPENC (2,1,8,6,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf23_el1",	CPENC (2,1,8,7,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf24_el1",	CPENC (2,1,8,8,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf25_el1",	CPENC (2,1,8,9,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf26_el1",	CPENC (2,1,8,10,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf27_el1",	CPENC (2,1,8,11,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf28_el1",	CPENC (2,1,8,12,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf29_el1",	CPENC (2,1,8,13,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf2_el1",	CPENC (2,1,8,2,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf30_el1",	CPENC (2,1,8,14,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf31_el1",	CPENC (2,1,8,15,4),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf3_el1",	CPENC (2,1,8,3,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf4_el1",	CPENC (2,1,8,4,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf5_el1",	CPENC (2,1,8,5,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf6_el1",	CPENC (2,1,8,6,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf7_el1",	CPENC (2,1,8,7,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf8_el1",	CPENC (2,1,8,8,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinf9_el1",	CPENC (2,1,8,9,0),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbinfinj_el1",	CPENC (2,1,9,1,0),	0,		AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc0_el1",	CPENC (2,1,8,0,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc10_el1",	CPENC (2,1,8,10,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc11_el1",	CPENC (2,1,8,11,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc12_el1",	CPENC (2,1,8,12,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc13_el1",	CPENC (2,1,8,13,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc14_el1",	CPENC (2,1,8,14,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc15_el1",	CPENC (2,1,8,15,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc16_el1",	CPENC (2,1,8,0,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc17_el1",	CPENC (2,1,8,1,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc18_el1",	CPENC (2,1,8,2,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc19_el1",	CPENC (2,1,8,3,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc1_el1",	CPENC (2,1,8,1,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc20_el1",	CPENC (2,1,8,4,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc21_el1",	CPENC (2,1,8,5,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc22_el1",	CPENC (2,1,8,6,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc23_el1",	CPENC (2,1,8,7,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc24_el1",	CPENC (2,1,8,8,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc25_el1",	CPENC (2,1,8,9,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc26_el1",	CPENC (2,1,8,10,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc27_el1",	CPENC (2,1,8,11,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc28_el1",	CPENC (2,1,8,12,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc29_el1",	CPENC (2,1,8,13,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc2_el1",	CPENC (2,1,8,2,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc30_el1",	CPENC (2,1,8,14,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc31_el1",	CPENC (2,1,8,15,5),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc3_el1",	CPENC (2,1,8,3,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc4_el1",	CPENC (2,1,8,4,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc5_el1",	CPENC (2,1,8,5,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc6_el1",	CPENC (2,1,8,6,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc7_el1",	CPENC (2,1,8,7,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc8_el1",	CPENC (2,1,8,8,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrc9_el1",	CPENC (2,1,8,9,1),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbsrcinj_el1",	CPENC (2,1,9,1,1),	0,		AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt0_el1",	CPENC (2,1,8,0,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt10_el1",	CPENC (2,1,8,10,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt11_el1",	CPENC (2,1,8,11,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt12_el1",	CPENC (2,1,8,12,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt13_el1",	CPENC (2,1,8,13,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt14_el1",	CPENC (2,1,8,14,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt15_el1",	CPENC (2,1,8,15,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt16_el1",	CPENC (2,1,8,0,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt17_el1",	CPENC (2,1,8,1,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt18_el1",	CPENC (2,1,8,2,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt19_el1",	CPENC (2,1,8,3,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt1_el1",	CPENC (2,1,8,1,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt20_el1",	CPENC (2,1,8,4,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt21_el1",	CPENC (2,1,8,5,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt22_el1",	CPENC (2,1,8,6,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt23_el1",	CPENC (2,1,8,7,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt24_el1",	CPENC (2,1,8,8,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt25_el1",	CPENC (2,1,8,9,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt26_el1",	CPENC (2,1,8,10,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt27_el1",	CPENC (2,1,8,11,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt28_el1",	CPENC (2,1,8,12,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt29_el1",	CPENC (2,1,8,13,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt2_el1",	CPENC (2,1,8,2,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt30_el1",	CPENC (2,1,8,14,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt31_el1",	CPENC (2,1,8,15,6),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt3_el1",	CPENC (2,1,8,3,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt4_el1",	CPENC (2,1,8,4,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt5_el1",	CPENC (2,1,8,5,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt6_el1",	CPENC (2,1,8,6,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt7_el1",	CPENC (2,1,8,7,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt8_el1",	CPENC (2,1,8,8,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgt9_el1",	CPENC (2,1,8,9,2),	F_REG_READ,	AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbtgtinj_el1",	CPENC (2,1,9,1,2),	0,		AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("brbts_el1",		CPENC (2,1,9,0,2),	0,		AARCH64_FEATURE (V9_1A)) /* BRBE */
  SYSREG ("ccsidr2_el1",	CPENC (3,1,0,0,2),	F_REG_READ,	AARCH64_FEATURE (V8_2A)) /* CCIDX */
  SYSREG ("ccsidr_el1",		CPENC (3,1,0,0,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("clidr_el1",		CPENC (3,1,0,0,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("cntfrq_el0",		CPENC (3,3,14,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cnthctl_el2",	CPENC (3,4,14,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cnthp_ctl_el2",	CPENC (3,4,14,2,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cnthp_cval_el2",	CPENC (3,4,14,2,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cnthp_tval_el2",	CPENC (3,4,14,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cnthps_ctl_el2",	CPENC (3,4,14,5,1),	0,		AARCH64_FEATURE (V8_3A)) /* SEL2 */
  SYSREG ("cnthps_cval_el2",	CPENC (3,4,14,5,2),	0,		AARCH64_FEATURE (V8_3A)) /* SEL2 */
  SYSREG ("cnthps_tval_el2",	CPENC (3,4,14,5,0),	0,		AARCH64_FEATURE (V8_3A)) /* SEL2 */
  SYSREG ("cnthv_ctl_el2",	CPENC (3,4,14,3,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cnthv_cval_el2",	CPENC (3,4,14,3,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cnthv_tval_el2",	CPENC (3,4,14,3,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cnthvs_ctl_el2",	CPENC (3,4,14,4,1),	0,		AARCH64_FEATURE (V8_3A)) /* SEL2 */
  SYSREG ("cnthvs_cval_el2",	CPENC (3,4,14,4,2),	0,		AARCH64_FEATURE (V8_3A)) /* SEL2 */
  SYSREG ("cnthvs_tval_el2",	CPENC (3,4,14,4,0),	0,		AARCH64_FEATURE (V8_3A)) /* SEL2 */
  SYSREG ("cntkctl_el1",	CPENC (3,0,14,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntkctl_el12",	CPENC (3,5,14,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntp_ctl_el0",	CPENC (3,3,14,2,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntp_ctl_el02",	CPENC (3,5,14,2,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntp_cval_el0",	CPENC (3,3,14,2,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntp_cval_el02",	CPENC (3,5,14,2,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntp_tval_el0",	CPENC (3,3,14,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntp_tval_el02",	CPENC (3,5,14,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntpct_el0",		CPENC (3,3,14,0,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("cntpctss_el0",	CPENC (3,3,14,0,5),	F_REG_READ,	AARCH64_FEATURE (V8_5A)) /* ECV */
  SYSREG ("cntpoff_el2",	CPENC (3,4,14,0,6),	0,		AARCH64_FEATURE (V8_5A)) /* ECV_POFF */
  SYSREG ("cntps_ctl_el1",	CPENC (3,7,14,2,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntps_cval_el1",	CPENC (3,7,14,2,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntps_tval_el1",	CPENC (3,7,14,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntv_ctl_el0",	CPENC (3,3,14,3,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntv_ctl_el02",	CPENC (3,5,14,3,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntv_cval_el0",	CPENC (3,3,14,3,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntv_cval_el02",	CPENC (3,5,14,3,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntv_tval_el0",	CPENC (3,3,14,3,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntv_tval_el02",	CPENC (3,5,14,3,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cntvct_el0",		CPENC (3,3,14,0,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("cntvctss_el0",	CPENC (3,3,14,0,6),	F_REG_READ,	AARCH64_FEATURE (V8_5A)) /* ECV */
  SYSREG ("cntvoff_el2",	CPENC (3,4,14,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("contextidr_el1",	CPENC (3,0,13,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("contextidr_el12",	CPENC (3,5,13,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("contextidr_el2",	CPENC (3,4,13,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cpacr_el1",		CPENC (3,0,1,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cpacr_el12",		CPENC (3,5,1,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cpacralias_el1",	CPENC (3,0,1,4,4),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("cpacrmask_el1",	CPENC (3,0,1,4,2),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("cpacrmask_el12",	CPENC (3,5,1,4,2),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("cptr_el2",		CPENC (3,4,1,1,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cptr_el3",		CPENC (3,6,1,1,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("cptrmask_el2",	CPENC (3,4,1,4,2),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("csselr_el1",		CPENC (3,2,0,0,0),	0,		AARCH64_NO_FEATURES) 
  SYSREG ("ctr_el0",		CPENC (3,3,0,0,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("currentel",		CPENC (3,0,4,2,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("dacr32_el2",		CPENC (3,4,3,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("daif",		CPENC (3,3,4,2,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgauthstatus_el1",	CPENC (2,0,7,14,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr0_el1",	CPENC (2,0,0,0,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr10_el1",	CPENC (2,0,0,10,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr11_el1",	CPENC (2,0,0,11,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr12_el1",	CPENC (2,0,0,12,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr13_el1",	CPENC (2,0,0,13,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr14_el1",	CPENC (2,0,0,14,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr15_el1",	CPENC (2,0,0,15,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr1_el1",	CPENC (2,0,0,1,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr2_el1",	CPENC (2,0,0,2,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr3_el1",	CPENC (2,0,0,3,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr4_el1",	CPENC (2,0,0,4,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr5_el1",	CPENC (2,0,0,5,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr6_el1",	CPENC (2,0,0,6,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr7_el1",	CPENC (2,0,0,7,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr8_el1",	CPENC (2,0,0,8,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbcr9_el1",	CPENC (2,0,0,9,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr0_el1",	CPENC (2,0,0,0,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr10_el1",	CPENC (2,0,0,10,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr11_el1",	CPENC (2,0,0,11,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr12_el1",	CPENC (2,0,0,12,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr13_el1",	CPENC (2,0,0,13,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr14_el1",	CPENC (2,0,0,14,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr15_el1",	CPENC (2,0,0,15,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr1_el1",	CPENC (2,0,0,1,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr2_el1",	CPENC (2,0,0,2,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr3_el1",	CPENC (2,0,0,3,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr4_el1",	CPENC (2,0,0,4,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr5_el1",	CPENC (2,0,0,5,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr6_el1",	CPENC (2,0,0,6,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr7_el1",	CPENC (2,0,0,7,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr8_el1",	CPENC (2,0,0,8,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgbvr9_el1",	CPENC (2,0,0,9,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgclaimclr_el1",	CPENC (2,0,7,9,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgclaimset_el1",	CPENC (2,0,7,8,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgdtr_el0",		CPENC (2,3,0,4,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgdtrrx_el0",	CPENC (2,3,0,5,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("dbgdtrtx_el0",	CPENC (2,3,0,5,0),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("dbgprcr_el1",	CPENC (2,0,1,4,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgvcr32_el2",	CPENC (2,4,0,7,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr0_el1",	CPENC (2,0,0,0,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr10_el1",	CPENC (2,0,0,10,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr11_el1",	CPENC (2,0,0,11,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr12_el1",	CPENC (2,0,0,12,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr13_el1",	CPENC (2,0,0,13,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr14_el1",	CPENC (2,0,0,14,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr15_el1",	CPENC (2,0,0,15,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr1_el1",	CPENC (2,0,0,1,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr2_el1",	CPENC (2,0,0,2,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr3_el1",	CPENC (2,0,0,3,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr4_el1",	CPENC (2,0,0,4,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr5_el1",	CPENC (2,0,0,5,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr6_el1",	CPENC (2,0,0,6,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr7_el1",	CPENC (2,0,0,7,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr8_el1",	CPENC (2,0,0,8,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwcr9_el1",	CPENC (2,0,0,9,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr0_el1",	CPENC (2,0,0,0,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr10_el1",	CPENC (2,0,0,10,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr11_el1",	CPENC (2,0,0,11,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr12_el1",	CPENC (2,0,0,12,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr13_el1",	CPENC (2,0,0,13,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr14_el1",	CPENC (2,0,0,14,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr15_el1",	CPENC (2,0,0,15,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr1_el1",	CPENC (2,0,0,1,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr2_el1",	CPENC (2,0,0,2,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr3_el1",	CPENC (2,0,0,3,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr4_el1",	CPENC (2,0,0,4,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr5_el1",	CPENC (2,0,0,5,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr6_el1",	CPENC (2,0,0,6,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr7_el1",	CPENC (2,0,0,7,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr8_el1",	CPENC (2,0,0,8,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dbgwvr9_el1",	CPENC (2,0,0,9,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dczid_el0",		CPENC (3,3,0,0,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("disr_el1",		CPENC (3,0,12,1,1),	0,		AARCH64_FEATURE (RAS))
  SYSREG ("dit",		CPENC (3,3,4,2,5),	0,		AARCH64_FEATURE (V8_3A)) /* DIT */
  SYSREG ("dlr_el0",		CPENC (3,3,4,5,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("dpocr_el0",		CPENC (3,3,4,5,2),      0,		AARCH64_FEATURE (POE2))
  SYSREG ("dpotbr0_el1",	CPENC (3,0,2,0,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("dpotbr0_el12",	CPENC (3,5,2,0,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("dpotbr0_el2",	CPENC (3,4,2,0,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("dpotbr0_el3",	CPENC (3,6,2,0,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("dpotbr1_el1",	CPENC (3,0,2,0,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("dpotbr1_el12",	CPENC (3,5,2,0,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("dpotbr1_el2",	CPENC (3,4,2,0,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("dspsr_el0",		CPENC (3,3,4,5,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("elr_el1",		CPENC (3,0,4,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("elr_el12",		CPENC (3,5,4,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("elr_el2",		CPENC (3,4,4,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("elr_el3",		CPENC (3,6,4,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("erridr_el1",		CPENC (3,0,5,3,0),	F_REG_READ,	AARCH64_FEATURE (RAS))
  SYSREG ("errselr_el1",	CPENC (3,0,5,3,1),	0,		AARCH64_FEATURE (RAS))
  SYSREG ("erxaddr_el1",	CPENC (3,0,5,4,3),	0,		AARCH64_FEATURE (RAS))
  SYSREG ("erxctlr_el1",	CPENC (3,0,5,4,1),	0,		AARCH64_FEATURE (RAS))
  SYSREG ("erxfr_el1",		CPENC (3,0,5,4,0),	F_REG_READ,	AARCH64_FEATURE (RAS))
  SYSREG ("erxgsr_el1",		CPENC (3,0,5,3,2),	F_REG_READ,	AARCH64_FEATURE (RASv2))
  SYSREG ("erxmisc0_el1",	CPENC (3,0,5,5,0),	0,		AARCH64_FEATURE (RAS))
  SYSREG ("erxmisc1_el1",	CPENC (3,0,5,5,1),	0,		AARCH64_FEATURE (RAS))
  SYSREG ("erxmisc2_el1",	CPENC (3,0,5,5,2),	0,		AARCH64_FEATURE (RAS)) /* RASv1p1 */
  SYSREG ("erxmisc3_el1",	CPENC (3,0,5,5,3),	0,		AARCH64_FEATURE (RAS)) /* RASv1p1 */
  SYSREG ("erxpfgcdn_el1",	CPENC (3,0,5,4,6),	0,		AARCH64_FEATURE (RAS)) /* RASv1p1 */
  SYSREG ("erxpfgctl_el1",	CPENC (3,0,5,4,5),	0,		AARCH64_FEATURE (RAS)) /* RASv1p1 */
  SYSREG ("erxpfgf_el1",	CPENC (3,0,5,4,4),	F_REG_READ,	AARCH64_FEATURE (RAS)) /* RASv1p1 */
  SYSREG ("erxstatus_el1",	CPENC (3,0,5,4,2),	0,		AARCH64_FEATURE (RAS))
  SYSREG ("esr_el1",		CPENC (3,0,5,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("esr_el12",		CPENC (3,5,5,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("esr_el2",		CPENC (3,4,5,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("esr_el3",		CPENC (3,6,5,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("far_el1",		CPENC (3,0,6,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("far_el12",		CPENC (3,5,6,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("far_el2",		CPENC (3,4,6,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("far_el3",		CPENC (3,6,6,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("fgdtp0_el1",		CPENC (3,0,3,2,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp0_el12",	CPENC (3,5,3,2,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp0_el2",		CPENC (3,4,3,2,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp0_el3",		CPENC (3,6,3,2,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp10_el1",	CPENC (3,0,3,3,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp10_el12",	CPENC (3,5,3,3,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp10_el2",	CPENC (3,4,3,3,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp10_el3",	CPENC (3,6,3,3,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp11_el1",	CPENC (3,0,3,3,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp11_el12",	CPENC (3,5,3,3,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp11_el2",	CPENC (3,4,3,3,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp11_el3",	CPENC (3,6,3,3,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp12_el1",	CPENC (3,0,3,3,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp12_el12",	CPENC (3,5,3,3,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp12_el2",	CPENC (3,4,3,3,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp12_el3",	CPENC (3,6,3,3,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp13_el1",	CPENC (3,0,3,3,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp13_el12",	CPENC (3,5,3,3,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp13_el2",	CPENC (3,4,3,3,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp13_el3",	CPENC (3,6,3,3,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp14_el1",	CPENC (3,0,3,3,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp14_el12",	CPENC (3,5,3,3,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp14_el2",	CPENC (3,4,3,3,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp14_el3",	CPENC (3,6,3,3,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp15_el1",	CPENC (3,0,3,3,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp15_el12",	CPENC (3,5,3,3,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp15_el2",	CPENC (3,4,3,3,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp15_el3",	CPENC (3,6,3,3,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp1_el1",		CPENC (3,0,3,2,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp1_el12",	CPENC (3,5,3,2,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp1_el2",		CPENC (3,4,3,2,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp1_el3",		CPENC (3,6,3,2,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp2_el1",		CPENC (3,0,3,2,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp2_el12",	CPENC (3,5,3,2,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp2_el2",		CPENC (3,4,3,2,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp2_el3",		CPENC (3,6,3,2,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp3_el1",		CPENC (3,0,3,2,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp3_el12",	CPENC (3,5,3,2,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp3_el2",		CPENC (3,4,3,2,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp3_el3",		CPENC (3,6,3,2,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp4_el1",		CPENC (3,0,3,2,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp4_el12",	CPENC (3,5,3,2,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp4_el2",		CPENC (3,4,3,2,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp4_el3",		CPENC (3,6,3,2,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp5_el1",		CPENC (3,0,3,2,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp5_el12",	CPENC (3,5,3,2,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp5_el2",		CPENC (3,4,3,2,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp5_el3",		CPENC (3,6,3,2,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp6_el1",		CPENC (3,0,3,2,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp6_el12",	CPENC (3,5,3,2,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp6_el2",		CPENC (3,4,3,2,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp6_el3",		CPENC (3,6,3,2,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp7_el1",		CPENC (3,0,3,2,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp7_el12",	CPENC (3,5,3,2,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp7_el2",		CPENC (3,4,3,2,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp7_el3",		CPENC (3,6,3,2,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp8_el1",		CPENC (3,0,3,3,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp8_el12",	CPENC (3,5,3,3,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp8_el2",		CPENC (3,4,3,3,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp8_el3",		CPENC (3,6,3,3,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp9_el1",		CPENC (3,0,3,3,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp9_el12",	CPENC (3,5,3,3,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp9_el2",		CPENC (3,4,3,3,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtp9_el3",		CPENC (3,6,3,3,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu0_el1",		CPENC (3,0,3,4,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu0_el12",	CPENC (3,5,3,4,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu0_el2",		CPENC (3,4,3,4,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu10_el1",	CPENC (3,0,3,5,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu10_el12",	CPENC (3,5,3,5,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu10_el2",	CPENC (3,4,3,5,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu11_el1",	CPENC (3,0,3,5,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu11_el12",	CPENC (3,5,3,5,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu11_el2",	CPENC (3,4,3,5,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu12_el1",	CPENC (3,0,3,5,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu12_el12",	CPENC (3,5,3,5,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu12_el2",	CPENC (3,4,3,5,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu13_el1",	CPENC (3,0,3,5,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu13_el12",	CPENC (3,5,3,5,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu13_el2",	CPENC (3,4,3,5,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu14_el1",	CPENC (3,0,3,5,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu14_el12",	CPENC (3,5,3,5,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu14_el2",	CPENC (3,4,3,5,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu15_el1",	CPENC (3,0,3,5,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu15_el12",	CPENC (3,5,3,5,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu15_el2",	CPENC (3,4,3,5,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu1_el1",		CPENC (3,0,3,4,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu1_el12",	CPENC (3,5,3,4,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu1_el2",		CPENC (3,4,3,4,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu2_el1",		CPENC (3,0,3,4,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu2_el12",	CPENC (3,5,3,4,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu2_el2",		CPENC (3,4,3,4,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu3_el1",		CPENC (3,0,3,4,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu3_el12",	CPENC (3,5,3,4,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu3_el2",		CPENC (3,4,3,4,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu4_el1",		CPENC (3,0,3,4,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu4_el12",	CPENC (3,5,3,4,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu4_el2",		CPENC (3,4,3,4,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu5_el1",		CPENC (3,0,3,4,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu5_el12",	CPENC (3,5,3,4,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu5_el2",		CPENC (3,4,3,4,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu6_el1",		CPENC (3,0,3,4,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu6_el12",	CPENC (3,5,3,4,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu6_el2",		CPENC (3,4,3,4,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu7_el1",		CPENC (3,0,3,4,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu7_el12",	CPENC (3,5,3,4,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu7_el2",		CPENC (3,4,3,4,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu8_el1",		CPENC (3,0,3,5,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu8_el12",	CPENC (3,5,3,5,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu8_el2",		CPENC (3,4,3,5,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu9_el1",		CPENC (3,0,3,5,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu9_el12",	CPENC (3,5,3,5,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgdtu9_el2",		CPENC (3,4,3,5,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("fgwte3_el3",		CPENC (3,6,1,1,5),	0,		AARCH64_FEATURE (V9_4A)) /* FGWTE3 */
  SYSREG ("fpcr",		CPENC (3,3,4,4,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("fpexc32_el2",	CPENC (3,4,5,3,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("fpmr",		CPENC (3,3,4,4,2),	0,		AARCH64_FEATURE (FP8))
  SYSREG ("fpsr",		CPENC (3,3,4,4,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("gcr_el1",		CPENC (3,0,1,0,6),	0,		AARCH64_FEATURE (MEMTAG))
  SYSREG ("gcscr_el1",		CPENC (3,0,2,5,0),    	0,		AARCH64_FEATURE (GCS))
  SYSREG ("gcscr_el12",		CPENC (3,5,2,5,0),    	0,		AARCH64_FEATURE (GCS))
  SYSREG ("gcscr_el2",		CPENC (3,4,2,5,0),    	0,		AARCH64_FEATURE (GCS))
  SYSREG ("gcscr_el3",		CPENC (3,6,2,5,0),    	0,		AARCH64_FEATURE (GCS))
  SYSREG ("gcscre0_el1",	CPENC (3,0,2,5,2),    	0,		AARCH64_FEATURE (GCS))
  SYSREG ("gcspr_el0",		CPENC (3,3,2,5,1),    	0,		AARCH64_FEATURE (GCS))
  SYSREG ("gcspr_el1",		CPENC (3,0,2,5,1),    	0,		AARCH64_FEATURE (GCS))
  SYSREG ("gcspr_el12",		CPENC (3,5,2,5,1),    	0,		AARCH64_FEATURE (GCS))
  SYSREG ("gcspr_el2",		CPENC (3,4,2,5,1),    	0,		AARCH64_FEATURE (GCS))
  SYSREG ("gcspr_el3",		CPENC (3,6,2,5,1),    	0,		AARCH64_FEATURE (GCS))
  SYSREG ("gmid_el1",		CPENC (3,1,0,0,4),	F_REG_READ,	AARCH64_FEATURE (MEMTAG))
  SYSREG ("gpcbw_el3",		CPENC (3,6,2,1,5),	0,		AARCH64_FEATURE (V9_5A)) /* RME_GPC3 */
  SYSREG ("gpccr_el3",		CPENC (3,6,2,1,6),	0,		AARCH64_FEATURE (V9_1A)) /* RME */
  SYSREG ("gptbr_el3",		CPENC (3,6,2,1,4),	0,		AARCH64_FEATURE (V9_1A)) /* RME */
  SYSREG ("hacdbsbr_el2",	CPENC (3,4,2,3,4),	0,		AARCH64_FEATURE (V9_4A)) /* HACDBS */
  SYSREG ("hacdbscons_el2",	CPENC (3,4,2,3,5),	0,		AARCH64_FEATURE (V9_4A)) /* HACDBS */
  SYSREG ("hacr_el2",		CPENC (3,4,1,1,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("hafgrtr_el2",	CPENC (3,4,3,1,6),	0,		AARCH64_FEATURE (V8_5A)) /* AMUv1 && FGT */
  SYSREG ("hcr_el2",		CPENC (3,4,1,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("hcrx_el2",		CPENC (3,4,1,2,2),	0,		AARCH64_FEATURE (V8_6A)) /* HCX */
  SYSREG ("hcrmask_el2",	CPENC (3,4,1,5,6),	0,		AARCH64_FEATURE (V9_6A)) /* SRMASK2 */
  SYSREG ("hcrxmask_el2",	CPENC (3,4,1,5,7),	0,		AARCH64_FEATURE (V9_6A)) /* SRMASK2 */
  SYSREG ("hdbssbr_el2",	CPENC (3,4,2,3,2),	0,		AARCH64_FEATURE (V9_4A)) /* HDBSS */
  SYSREG ("hdbssprod_el2",	CPENC (3,4,2,3,3),	0,		AARCH64_FEATURE (V9_4A)) /* HDBSS */
  SYSREG ("hdfgrtr_el2",	CPENC (3,4,3,1,4),	0,		AARCH64_FEATURE (V8_5A)) /* FGT */
  SYSREG ("hdfgrtr2_el2",	CPENC (3,4,3,1,0),	0,		AARCH64_FEATURE (V8_8A)) /* FGT2 */
  SYSREG ("hdfgwtr_el2",	CPENC (3,4,3,1,5),	0,		AARCH64_FEATURE (V8_5A)) /* FGT */
  SYSREG ("hdfgwtr2_el2",	CPENC (3,4,3,1,1),	0,		AARCH64_FEATURE (V8_8A)) /* FGT2 */
  SYSREG ("hfgitr_el2",		CPENC (3,4,1,1,6),	0,		AARCH64_FEATURE (V8_5A)) /* FGT */
  SYSREG ("hfgitr2_el2",	CPENC (3,4,3,1,7),	0,		AARCH64_FEATURE (V8_8A)) /* FGT2 */
  SYSREG ("hfgrtr_el2",		CPENC (3,4,1,1,4),	0,		AARCH64_FEATURE (V8_5A)) /* FGT */
  SYSREG ("hfgrtr2_el2",	CPENC (3,4,3,1,2),	0,		AARCH64_FEATURE (V8_8A)) /* FGT2 */
  SYSREG ("hfgwtr_el2",		CPENC (3,4,1,1,5),	0,		AARCH64_FEATURE (V8_5A)) /* FGT */
  SYSREG ("hfgwtr2_el2",	CPENC (3,4,3,1,3),	0,		AARCH64_FEATURE (V8_8A)) /* FGT2 */
  SYSREG ("hpfar_el2",		CPENC (3,4,6,0,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("hstr_el2",		CPENC (3,4,1,1,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_apr_el1",	CPENC (3,1,12,0,0),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_apr_el3",	CPENC (3,6,12,8,0),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ap0r0_el1",	CPENC (3,0,12,8,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_ap0r1_el1",	CPENC (3,0,12,8,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_ap0r2_el1",	CPENC (3,0,12,8,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_ap0r3_el1",	CPENC (3,0,12,8,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_ap1r0_el1",	CPENC (3,0,12,9,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_ap1r1_el1",	CPENC (3,0,12,9,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_ap1r2_el1",	CPENC (3,0,12,9,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_ap1r3_el1",	CPENC (3,0,12,9,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_asgi1r_el1",	CPENC (3,0,12,11,6),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("icc_bpr0_el1",	CPENC (3,0,12,8,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_bpr1_el1",	CPENC (3,0,12,12,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_cr0_el1",	CPENC (3,1,12,0,1),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_cr0_el3",	CPENC (3,6,12,9,0),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ctlr_el1",	CPENC (3,0,12,12,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_ctlr_el3",	CPENC (3,6,12,12,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_dir_el1",	CPENC (3,0,12,11,1),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("icc_domhppir_el3",	CPENC (3,6,12,8,2),	F_REG_READ,	AARCH64_FEATURE (GCIE))
  SYSREG ("icc_eoir0_el1",	CPENC (3,0,12,8,1),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("icc_eoir1_el1",	CPENC (3,0,12,12,1),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("icc_hapr_el1",	CPENC (3,1,12,0,3),	F_REG_READ,	AARCH64_FEATURE (GCIE))
  SYSREG ("icc_hppir_el1",	CPENC (3,0,12,10,3),	F_REG_READ,	AARCH64_FEATURE (GCIE))
  SYSREG ("icc_hppir_el3",	CPENC (3,6,12,9,1),	F_REG_READ,	AARCH64_FEATURE (GCIE))
  SYSREG ("icc_hppir0_el1",	CPENC (3,0,12,8,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("icc_hppir1_el1",	CPENC (3,0,12,12,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("icc_iaffidr_el1",	CPENC (3,0,12,10,5),	F_REG_READ,	AARCH64_FEATURE (GCIE))
  SYSREG ("icc_iar0_el1",	CPENC (3,0,12,8,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("icc_iar1_el1",	CPENC (3,0,12,12,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("icc_icsr_el1",	CPENC (3,0,12,10,4),	0,		AARCH64_FEATURE (GCIE))
  SYSREG ("icc_idr0_el1",	CPENC (3,0,12,10,2),	F_REG_READ,	AARCH64_FEATURE (GCIE))
  SYSREG ("icc_igrpen0_el1",	CPENC (3,0,12,12,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_igrpen1_el1",	CPENC (3,0,12,12,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_igrpen1_el3",	CPENC (3,6,12,12,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_nmiar1_el1",	CPENC (3,0,12,9,5),	F_REG_READ,	AARCH64_FEATURE (V8_7A)) /* GICv3_NMI */
  SYSREG ("icc_pcr_el1",	CPENC (3,1,12,0,2),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_pcr_el3",	CPENC (3,6,12,8,1),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_pmr_el1",	CPENC (3,0,4,6,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_ppi_cactiver0_el1", CPENC (3,0,12,13,0),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_cactiver1_el1", CPENC (3,0,12,13,1),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_cpendr0_el1",   CPENC (3,0,12,13,4),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_cpendr1_el1",   CPENC (3,0,12,13,5),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_domainr0_el3",  CPENC (3,6,12,8,4),  0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_domainr1_el3",  CPENC (3,6,12,8,5),  0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_domainr2_el3",  CPENC (3,6,12,8,6),  0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_domainr3_el3",  CPENC (3,6,12,8,7),  0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_enabler0_el1",  CPENC (3,0,12,10,6), 0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_enabler1_el1",  CPENC (3,0,12,10,7), 0,              AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_hmr0_el1",	CPENC (3,0,12,10,0),	F_REG_READ,     AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_hmr1_el1",	CPENC (3,0,12,10,1),	F_REG_READ,     AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr0_el1",  CPENC (3,0,12,14,0), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr1_el1",  CPENC (3,0,12,14,1), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr2_el1",  CPENC (3,0,12,14,2), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr3_el1",  CPENC (3,0,12,14,3), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr4_el1",  CPENC (3,0,12,14,4), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr5_el1",  CPENC (3,0,12,14,5), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr6_el1",  CPENC (3,0,12,14,6), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr7_el1",  CPENC (3,0,12,14,7), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr8_el1",  CPENC (3,0,12,15,0), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr9_el1",  CPENC (3,0,12,15,1), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr10_el1", CPENC (3,0,12,15,2), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr11_el1", CPENC (3,0,12,15,3), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr12_el1", CPENC (3,0,12,15,4), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr13_el1", CPENC (3,0,12,15,5), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr14_el1", CPENC (3,0,12,15,6), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_priorityr15_el1", CPENC (3,0,12,15,7), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_sactiver0_el1",   CPENC (3,0,12,13,2), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_sactiver1_el1",   CPENC (3,0,12,13,3), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_spendr0_el1",     CPENC (3,0,12,13,6), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_ppi_spendr1_el1",     CPENC (3,0,12,13,7), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("icc_rpr_el1",	CPENC (3,0,12,11,3),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("icc_sgi0r_el1",	CPENC (3,0,12,11,7),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("icc_sgi1r_el1",	CPENC (3,0,12,11,5),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("icc_sre_el1",	CPENC (3,0,12,12,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_sre_el2",	CPENC (3,4,12,9,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("icc_sre_el3",	CPENC (3,6,12,12,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_ap0r0_el2",	CPENC (3,4,12,8,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_ap0r1_el2",	CPENC (3,4,12,8,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_ap0r2_el2",	CPENC (3,4,12,8,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_ap0r3_el2",	CPENC (3,4,12,8,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_ap1r0_el2",	CPENC (3,4,12,9,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_ap1r1_el2",	CPENC (3,4,12,9,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_ap1r2_el2",	CPENC (3,4,12,9,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_ap1r3_el2",	CPENC (3,4,12,9,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_apr_el2",	CPENC (3,4,12,8,4),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_contextr_el2",	CPENC (3,4,12,11,6),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_eisr_el2",	CPENC (3,4,12,11,3),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("ich_elrsr_el2",	CPENC (3,4,12,11,5),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("ich_hcr_el2",	CPENC (3,4,12,11,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_hfgitr_el2",	CPENC (3,4,12,9,7),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_hfgrtr_el2",	CPENC (3,4,12,9,4),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_hfgwtr_el2",	CPENC (3,4,12,9,6),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_hppir_el2",	CPENC (3,4,12,8,5),	F_REG_READ,     AARCH64_FEATURE (GCIE))
  SYSREG ("ich_lr0_el2",	CPENC (3,4,12,12,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr10_el2",	CPENC (3,4,12,13,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr11_el2",	CPENC (3,4,12,13,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr12_el2",	CPENC (3,4,12,13,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr13_el2",	CPENC (3,4,12,13,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr14_el2",	CPENC (3,4,12,13,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr15_el2",	CPENC (3,4,12,13,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr1_el2",	CPENC (3,4,12,12,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr2_el2",	CPENC (3,4,12,12,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr3_el2",	CPENC (3,4,12,12,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr4_el2",	CPENC (3,4,12,12,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr5_el2",	CPENC (3,4,12,12,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr6_el2",	CPENC (3,4,12,12,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr7_el2",	CPENC (3,4,12,12,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr8_el2",	CPENC (3,4,12,13,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_lr9_el2",	CPENC (3,4,12,13,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_misr_el2",	CPENC (3,4,12,11,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("ich_ppi_activer0_el2", CPENC (3,4,12,10,6),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_activer1_el2", CPENC (3,4,12,10,7),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_dvir0_el2", CPENC (3,4,12,10,0),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_dvir1_el2", CPENC (3,4,12,10,1),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_enabler0_el2", CPENC (3,4,12,10,2),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_enabler1_el2", CPENC (3,4,12,10,3),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_pendr0_el2", CPENC (3,4,12,10,4),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_pendr1_el2", CPENC (3,4,12,10,5),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr0_el2",  CPENC (3,4,12,14,0), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr1_el2",  CPENC (3,4,12,14,1), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr2_el2",  CPENC (3,4,12,14,2), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr3_el2",  CPENC (3,4,12,14,3), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr4_el2",  CPENC (3,4,12,14,4), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr5_el2",  CPENC (3,4,12,14,5), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr6_el2",  CPENC (3,4,12,14,6), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr7_el2",  CPENC (3,4,12,14,7), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr8_el2",  CPENC (3,4,12,15,0), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr9_el2",  CPENC (3,4,12,15,1), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr10_el2", CPENC (3,4,12,15,2), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr11_el2", CPENC (3,4,12,15,3), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr12_el2", CPENC (3,4,12,15,4), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr13_el2", CPENC (3,4,12,15,5), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr14_el2", CPENC (3,4,12,15,6), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_ppi_priorityr15_el2", CPENC (3,4,12,15,7), 0,            AARCH64_FEATURE (GCIE))
  SYSREG ("ich_vctlr_el2",	CPENC (3,4,12,11,4),	0,              AARCH64_FEATURE (GCIE))
  SYSREG ("ich_vmcr_el2",	CPENC (3,4,12,11,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ich_vtr_el2",	CPENC (3,4,12,11,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64afr0_el1",	CPENC (3,0,0,5,4),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64afr1_el1",	CPENC (3,0,0,5,5),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64dfr0_el1",	CPENC (3,0,0,5,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64dfr1_el1",	CPENC (3,0,0,5,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64dfr2_el1",	CPENC (3,0,0,5,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64fpfr0_el1",	CPENC (3,0,0,4,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64isar0_el1",	CPENC (3,0,0,6,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64isar1_el1",	CPENC (3,0,0,6,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64isar2_el1",	CPENC (3,0,0,6,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64isar3_el1",	CPENC (3,0,0,6,3),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64mmfr0_el1",	CPENC (3,0,0,7,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64mmfr1_el1",	CPENC (3,0,0,7,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64mmfr2_el1",	CPENC (3,0,0,7,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64mmfr3_el1",	CPENC (3,0,0,7,3),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64mmfr4_el1",	CPENC (3,0,0,7,4),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64pfr0_el1",	CPENC (3,0,0,4,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64pfr1_el1",	CPENC (3,0,0,4,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64pfr2_el1",	CPENC (3,0,0,4,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64smfr0_el1",	CPENC (3,0,0,4,5),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_aa64zfr0_el1",	CPENC (3,0,0,4,4),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_afr0_el1",	CPENC (3,0,0,1,3),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_dfr0_el1",	CPENC (3,0,0,1,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_dfr1_el1",	CPENC (3,0,0,3,5),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_isar0_el1",	CPENC (3,0,0,2,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_isar1_el1",	CPENC (3,0,0,2,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_isar2_el1",	CPENC (3,0,0,2,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_isar3_el1",	CPENC (3,0,0,2,3),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_isar4_el1",	CPENC (3,0,0,2,4),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_isar5_el1",	CPENC (3,0,0,2,5),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_isar6_el1",	CPENC (3,0,0,2,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_mmfr0_el1",	CPENC (3,0,0,1,4),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_mmfr1_el1",	CPENC (3,0,0,1,5),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_mmfr2_el1",	CPENC (3,0,0,1,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_mmfr3_el1",	CPENC (3,0,0,1,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_mmfr4_el1",	CPENC (3,0,0,2,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_mmfr5_el1",	CPENC (3,0,0,3,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_pfr0_el1",	CPENC (3,0,0,1,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_pfr1_el1",	CPENC (3,0,0,1,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("id_pfr2_el1",	CPENC (3,0,0,3,4),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("ifsr32_el2",		CPENC (3,4,5,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("irtbrp_el1",		CPENC (3,0,2,0,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("irtbrp_el12",	CPENC (3,5,2,0,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("irtbrp_el2",		CPENC (3,4,2,0,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("irtbrp_el3",		CPENC (3,6,2,0,5),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("irtbru_el1",		CPENC (3,0,2,0,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("irtbru_el12",	CPENC (3,5,2,0,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("irtbru_el2",		CPENC (3,4,2,0,4),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("isr_el1",		CPENC (3,0,12,1,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("ldstt_el1",		CPENC (3,0,2,1,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("ldstt_el12",		CPENC (3,5,2,1,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("ldstt_el2",		CPENC (3,4,2,1,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("lorc_el1",		CPENC (3,0,10,4,3),	0,		AARCH64_FEATURE (LOR))
  SYSREG ("lorea_el1",		CPENC (3,0,10,4,1),	0,		AARCH64_FEATURE (LOR))
  SYSREG ("lorid_el1",		CPENC (3,0,10,4,7),	F_REG_READ,	AARCH64_FEATURE (LOR))
  SYSREG ("lorn_el1",		CPENC (3,0,10,4,2),	0,		AARCH64_FEATURE (LOR))
  SYSREG ("lorsa_el1",		CPENC (3,0,10,4,0),	0,		AARCH64_FEATURE (LOR))
  SYSREG ("mair_el1",		CPENC (3,0,10,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("mair_el12",		CPENC (3,5,10,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("mair_el2",		CPENC (3,4,10,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("mair_el3",		CPENC (3,6,10,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("mair2_el1",		CPENC (3,0,10,2,1),	0,		AARCH64_FEATURE (V8_8A)) /* AIE */
  SYSREG ("mair2_el12",		CPENC (3,5,10,2,1),	0,		AARCH64_FEATURE (V8_8A)) /* AIE */
  SYSREG ("mair2_el2",		CPENC (3,4,10,1,1),	0,		AARCH64_FEATURE (V8_8A)) /* AIE */
  SYSREG ("mair2_el3",		CPENC (3,6,10,1,1),	0,		AARCH64_FEATURE (V8_8A)) /* AIE */
  SYSREG ("mdccint_el1",	CPENC (2,0,0,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("mdccsr_el0",		CPENC (2,3,0,1,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("mdcr_el2",		CPENC (3,4,1,1,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("mdcr_el3",		CPENC (3,6,1,3,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("mdrar_el1",		CPENC (2,0,1,0,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("mdscr_el1",		CPENC (2,0,0,2,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("mdselr_el1",		CPENC (2,0,0,4,2),	0,		AARCH64_FEATURE (V8_8A)) /* Debugv8p9 */
  SYSREG ("mdstepop_el1",	CPENC (2,0,0,5,2),	0,		AARCH64_FEATURE (V9_4A)) /* STEP2 */
  SYSREG ("mecid_a0_el2",	CPENC (3,4,10,8,1),	0,		AARCH64_FEATURE (V9_2A)) /* MEC */
  SYSREG ("mecid_a1_el2",	CPENC (3,4,10,8,3),	0,		AARCH64_FEATURE (V9_2A)) /* MEC */
  SYSREG ("mecid_p0_el2",	CPENC (3,4,10,8,0),	0,		AARCH64_FEATURE (V9_2A)) /* MEC */
  SYSREG ("mecid_p1_el2",	CPENC (3,4,10,8,2),	0,		AARCH64_FEATURE (V9_2A)) /* MEC */
  SYSREG ("mecid_rl_a_el3",	CPENC (3,6,10,10,1),	0,		AARCH64_FEATURE (V9_2A)) /* MEC */
  SYSREG ("mecidr_el2",		CPENC (3,4,10,8,7),	F_REG_READ,	AARCH64_FEATURE (V9_2A)) /* MEC */
  SYSREG ("mfar_el3",		CPENC (3,6,6,0,5),	0,		AARCH64_FEATURE (V8_6A)) /* PFAR=>8.8 || RME=>9.1 */
  SYSREG ("midr_el1",		CPENC (3,0,0,0,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("mpam0_el1",		CPENC (3,0,10,5,1),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpam1_el1",		CPENC (3,0,10,5,0),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpam1_el12",		CPENC (3,5,10,5,0),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpam2_el2",		CPENC (3,4,10,5,0),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpam3_el3",		CPENC (3,6,10,5,0),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpambw0_el1",	CPENC (3,0,10,5,5),	0,		AARCH64_FEATURE (V9_3A)) /* MPAM_PE_BW_CTRL */
  SYSREG ("mpambw1_el1",	CPENC (3,0,10,5,4),	0,		AARCH64_FEATURE (V9_3A)) /* MPAM_PE_BW_CTRL */
  SYSREG ("mpambw1_el12",	CPENC (3,5,10,5,4),	0,		AARCH64_FEATURE (V9_3A)) /* MPAM_PE_BW_CTRL */
  SYSREG ("mpambw2_el2",	CPENC (3,4,10,5,4),	0,		AARCH64_FEATURE (V9_3A)) /* MPAM_PE_BW_CTRL */
  SYSREG ("mpambw3_el3",	CPENC (3,6,10,5,4),	0,		AARCH64_FEATURE (V9_3A)) /* MPAM_PE_BW_CTRL */
  SYSREG ("mpambwcap_el2",	CPENC (3,4,10,5,6),	0,		AARCH64_FEATURE (V9_3A)) /* MPAM_PE_BW_CTRL */
  SYSREG ("mpambwidr_el1",	CPENC (3,0,10,4,5),	F_REG_READ,	AARCH64_FEATURE (V9_3A)) /* MPAM_PE_BW_CTRL */
  SYSREG ("mpambwsm_el1",	CPENC (3,0,10,5,7),	0,		AARCH64_FEATURES (2, SME, V9_3A)) /* SME && MPAM_PE_BW_CTRL */
  SYSREG ("mpamctl_el1",	CPENC (3,0,10,5,2),	0,		AARCH64_FEATURE (MPAMv2))
  SYSREG ("mpamctl_el12",	CPENC (3,5,10,5,2),	0,		AARCH64_FEATURE (MPAMv2))
  SYSREG ("mpamctl_el2",	CPENC (3,4,10,5,2),	0,		AARCH64_FEATURE (MPAMv2))
  SYSREG ("mpamctl_el3",	CPENC (3,6,10,5,2),	0,		AARCH64_FEATURE (MPAMv2))
  SYSREG ("mpamhcr_el2",	CPENC (3,4,10,4,0),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpamidr_el1",	CPENC (3,0,10,4,4),	F_REG_READ,	AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpamsm_el1",		CPENC (3,0,10,5,3),	0,		AARCH64_FEATURES (2, SME, V8_2A)) /* SME && MPAM */
  SYSREG ("mpamvidcr_el2",	CPENC (3,4,10,7,0),	0,		AARCH64_FEATURE (MPAMv2))
  SYSREG ("mpamvidsr_el2",	CPENC (3,4,10,7,1),	0,		AARCH64_FEATURE (MPAMv2))
  SYSREG ("mpamvidsr_el3",	CPENC (3,6,10,7,1),	0,		AARCH64_FEATURE (MPAMv2))
  SYSREG ("mpamvpm0_el2",	CPENC (3,4,10,6,0),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpamvpm1_el2",	CPENC (3,4,10,6,1),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpamvpm2_el2",	CPENC (3,4,10,6,2),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpamvpm3_el2",	CPENC (3,4,10,6,3),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpamvpm4_el2",	CPENC (3,4,10,6,4),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpamvpm5_el2",	CPENC (3,4,10,6,5),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpamvpm6_el2",	CPENC (3,4,10,6,6),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpamvpm7_el2",	CPENC (3,4,10,6,7),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpamvpmv_el2",	CPENC (3,4,10,4,1),	0,		AARCH64_FEATURE (V8_2A)) /* MPAM */
  SYSREG ("mpidr_el1",		CPENC (3,0,0,0,5),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("mpuir_el1",		CPENC (3,0,0,0,4),	F_REG_READ,	AARCH64_FEATURE (V8R))
  SYSREG ("mpuir_el2",		CPENC (3,4,0,0,4),	F_REG_READ,	AARCH64_FEATURE (V8R))
  SYSREG ("mvfr0_el1",		CPENC (3,0,0,3,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("mvfr1_el1",		CPENC (3,0,0,3,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("mvfr2_el1",		CPENC (3,0,0,3,2),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("nvhcr_el2",		CPENC (3,4,1,5,0),	0,		AARCH64_FEATURE (V9_3A)) /* NV3 */
  SYSREG ("nvhcrx_el2",		CPENC (3,4,1,5,1),	0,		AARCH64_FEATURE (V9_6A)) /* NV3 && SRMASK2 */
  SYSREG ("nvhcrmask_el2",	CPENC (3,4,1,5,4),	0,		AARCH64_FEATURE (V9_6A)) /* NV3 && SRMASK2 */
  SYSREG ("nvhcrxmask_el2",	CPENC (3,4,1,5,5),	0,		AARCH64_FEATURE (V9_6A)) /* NV3 && SRMASK2 */
  SYSREG ("nzcv",		CPENC (3,3,4,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("osdlr_el1",		CPENC (2,0,1,3,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("osdtrrx_el1",	CPENC (2,0,0,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("osdtrtx_el1",	CPENC (2,0,0,3,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("oseccr_el1",		CPENC (2,0,0,6,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("oslar_el1",		CPENC (2,0,1,0,4),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("oslsr_el1",		CPENC (2,0,1,1,4),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("pan",		CPENC (3,0,4,2,3),	0,		AARCH64_FEATURE (PAN))
  SYSREG ("par_el1",		CPENC (3,0,7,4,0),	F_REG_128,	AARCH64_NO_FEATURES)
  SYSREG ("pfar_el1",		CPENC (3,0,6,0,5),      0,		AARCH64_FEATURE (V8_8A)) /* PFAR */
  SYSREG ("pfar_el12",		CPENC (3,5,6,0,5),      0,		AARCH64_FEATURE (V8_8A)) /* PFAR */
  SYSREG ("pfar_el2",		CPENC (3,4,6,0,5),      0,		AARCH64_FEATURE (V8_8A)) /* PFAR */
  SYSREG ("pir_el1",		CPENC (3,0,10,2,3),	0,		AARCH64_FEATURE (V8_8A)) /* S1PIE */
  SYSREG ("pir_el12",		CPENC (3,5,10,2,3),	0,		AARCH64_FEATURE (V8_8A)) /* S1PIE */
  SYSREG ("pir_el2",		CPENC (3,4,10,2,3),	0,		AARCH64_FEATURE (V8_8A)) /* S1PIE */
  SYSREG ("pir_el3",		CPENC (3,6,10,2,3),	0,		AARCH64_FEATURE (V8_8A)) /* S1PIE */
  SYSREG ("pire0_el1",		CPENC (3,0,10,2,2),	0,		AARCH64_FEATURE (V8_8A)) /* S1PIE */
  SYSREG ("pire0_el12",		CPENC (3,5,10,2,2),	0,		AARCH64_FEATURE (V8_8A)) /* S1PIE */
  SYSREG ("pire0_el2",		CPENC (3,4,10,2,2),	0,		AARCH64_FEATURE (V8_8A)) /* S1PIE */
  SYSREG ("pm",			CPENC (3,0,4,3,1),	0,		AARCH64_FEATURE (V9_3A)) /* EBEP */
  SYSREG ("pmbidr_el1",		CPENC (3,0,9,10,7),	F_REG_READ,	AARCH64_FEATURE (PROFILE))
  SYSREG ("pmblimitr_el1",	CPENC (3,0,9,10,0),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmbmar_el1",		CPENC (3,0,9,10,5),	0,		AARCH64_FEATURES (2, PROFILE, V9_5A)) /* SPE_nVM */
  SYSREG ("pmbptr_el1",		CPENC (3,0,9,10,1),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmbsr_el1",		CPENC (3,0,9,10,3),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmbsr_el12",		CPENC (3,5,9,10,3),	0,		AARCH64_FEATURES (2, V9_5A, PROFILE)) /* SPE_EXC */
  SYSREG ("pmbsr_el2",		CPENC (3,4,9,10,3),	0,		AARCH64_FEATURES (2, V9_5A, PROFILE)) /* SPE_EXC */
  SYSREG ("pmbsr_el3",		CPENC (3,6,9,10,3),	0,		AARCH64_FEATURES (2, V9_5A, PROFILE)) /* SPE_EXC */
  SYSREG ("pmccfiltr_el0",	CPENC (3,3,14,15,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmccntr_el0",	CPENC (3,3,9,13,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmccntsvr_el1",	CPENC (2,0,14,11,7),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmceid0_el0",	CPENC (3,3,9,12,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("pmceid1_el0",	CPENC (3,3,9,12,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("pmcntenclr_el0",	CPENC (3,3,9,12,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmcntenset_el0",	CPENC (3,3,9,12,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmcr_el0",		CPENC (3,3,9,12,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmecr_el1",		CPENC (3,0,9,14,5),	0,		AARCH64_FEATURE (V8_8A)) /* EBEP || PMUv3_SS */
  SYSREG ("pmevcntr0_el0",	CPENC (3,3,14,8,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr10_el0",	CPENC (3,3,14,9,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr11_el0",	CPENC (3,3,14,9,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr12_el0",	CPENC (3,3,14,9,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr13_el0",	CPENC (3,3,14,9,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr14_el0",	CPENC (3,3,14,9,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr15_el0",	CPENC (3,3,14,9,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr16_el0",	CPENC (3,3,14,10,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr17_el0",	CPENC (3,3,14,10,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr18_el0",	CPENC (3,3,14,10,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr19_el0",	CPENC (3,3,14,10,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr1_el0",	CPENC (3,3,14,8,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr20_el0",	CPENC (3,3,14,10,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr21_el0",	CPENC (3,3,14,10,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr22_el0",	CPENC (3,3,14,10,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr23_el0",	CPENC (3,3,14,10,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr24_el0",	CPENC (3,3,14,11,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr25_el0",	CPENC (3,3,14,11,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr26_el0",	CPENC (3,3,14,11,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr27_el0",	CPENC (3,3,14,11,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr28_el0",	CPENC (3,3,14,11,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr29_el0",	CPENC (3,3,14,11,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr2_el0",	CPENC (3,3,14,8,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr30_el0",	CPENC (3,3,14,11,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr3_el0",	CPENC (3,3,14,8,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr4_el0",	CPENC (3,3,14,8,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr5_el0",	CPENC (3,3,14,8,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr6_el0",	CPENC (3,3,14,8,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr7_el0",	CPENC (3,3,14,8,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr8_el0",	CPENC (3,3,14,9,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntr9_el0",	CPENC (3,3,14,9,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevcntsvr0_el1",	CPENC (2,0,14,8,0),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr10_el1",	CPENC (2,0,14,9,2),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr11_el1",	CPENC (2,0,14,9,3),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr12_el1",	CPENC (2,0,14,9,4),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr13_el1",	CPENC (2,0,14,9,5),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr14_el1",	CPENC (2,0,14,9,6),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr15_el1",	CPENC (2,0,14,9,7),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr16_el1",	CPENC (2,0,14,10,0),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr17_el1",	CPENC (2,0,14,10,1),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr18_el1",	CPENC (2,0,14,10,2),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr19_el1",	CPENC (2,0,14,10,3),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr1_el1",	CPENC (2,0,14,8,1),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr20_el1",	CPENC (2,0,14,10,4),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr21_el1",	CPENC (2,0,14,10,5),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr22_el1",	CPENC (2,0,14,10,6),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr23_el1",	CPENC (2,0,14,10,7),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr24_el1",	CPENC (2,0,14,11,0),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr25_el1",	CPENC (2,0,14,11,1),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr26_el1",	CPENC (2,0,14,11,2),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr27_el1",	CPENC (2,0,14,11,3),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr28_el1",	CPENC (2,0,14,11,4),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr29_el1",	CPENC (2,0,14,11,5),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr2_el1",	CPENC (2,0,14,8,2),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr30_el1",	CPENC (2,0,14,11,6),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr3_el1",	CPENC (2,0,14,8,3),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr4_el1",	CPENC (2,0,14,8,4),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr5_el1",	CPENC (2,0,14,8,5),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr6_el1",	CPENC (2,0,14,8,6),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr7_el1",	CPENC (2,0,14,8,7),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr8_el1",	CPENC (2,0,14,9,0),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevcntsvr9_el1",	CPENC (2,0,14,9,1),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmevtyper0_el0",	CPENC (3,3,14,12,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper10_el0",	CPENC (3,3,14,13,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper11_el0",	CPENC (3,3,14,13,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper12_el0",	CPENC (3,3,14,13,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper13_el0",	CPENC (3,3,14,13,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper14_el0",	CPENC (3,3,14,13,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper15_el0",	CPENC (3,3,14,13,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper16_el0",	CPENC (3,3,14,14,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper17_el0",	CPENC (3,3,14,14,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper18_el0",	CPENC (3,3,14,14,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper19_el0",	CPENC (3,3,14,14,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper1_el0",	CPENC (3,3,14,12,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper20_el0",	CPENC (3,3,14,14,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper21_el0",	CPENC (3,3,14,14,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper22_el0",	CPENC (3,3,14,14,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper23_el0",	CPENC (3,3,14,14,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper24_el0",	CPENC (3,3,14,15,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper25_el0",	CPENC (3,3,14,15,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper26_el0",	CPENC (3,3,14,15,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper27_el0",	CPENC (3,3,14,15,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper28_el0",	CPENC (3,3,14,15,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper29_el0",	CPENC (3,3,14,15,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper2_el0",	CPENC (3,3,14,12,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper30_el0",	CPENC (3,3,14,15,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper3_el0",	CPENC (3,3,14,12,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper4_el0",	CPENC (3,3,14,12,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper5_el0",	CPENC (3,3,14,12,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper6_el0",	CPENC (3,3,14,12,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper7_el0",	CPENC (3,3,14,12,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper8_el0",	CPENC (3,3,14,13,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmevtyper9_el0",	CPENC (3,3,14,13,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmiar_el1",		CPENC (3,0,9,14,7),	0,		AARCH64_FEATURE (V9_3A)) /* SEBEP */
  SYSREG ("pmicfiltr_el0",	CPENC (3,3,9,6,0),	0,		AARCH64_FEATURE (V8_8A)) /* PMUv3_ICNTR */
  SYSREG ("pmicntr_el0",	CPENC (3,3,9,4,0),	0,		AARCH64_FEATURE (V8_8A)) /* PMUv3_ICNTR */
  SYSREG ("pmicntsvr_el1",	CPENC (2,0,14,12,0),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* PMUv3_ICNTR && PMUv3_SS */
  SYSREG ("pmintenclr_el1",	CPENC (3,0,9,14,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmintenset_el1",	CPENC (3,0,9,14,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmmir_el1",		CPENC (3,0,9,14,6),	F_REG_READ,	AARCH64_FEATURE (V8_3A)) /* PMUv3p4 */
  SYSREG ("pmovsclr_el0",	CPENC (3,3,9,12,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmovsset_el0",	CPENC (3,3,9,14,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmscr_el1",		CPENC (3,0,9,9,0),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmscr_el12",		CPENC (3,5,9,9,0),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmscr_el2",		CPENC (3,4,9,9,0),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmsdsfr_el1",	CPENC (3,0,9,10,4),	0,		AARCH64_FEATURES (2, PROFILE, V8_8A)) /* SPE_FDS */
  SYSREG ("pmselr_el0",		CPENC (3,3,9,12,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmsevfr_el1",	CPENC (3,0,9,9,5),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmsfcr_el1",		CPENC (3,0,9,9,4),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmsicr_el1",		CPENC (3,0,9,9,2),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmsidr_el1",		CPENC (3,0,9,9,7),	F_REG_READ,	AARCH64_FEATURE (PROFILE))
  SYSREG ("pmsirr_el1",		CPENC (3,0,9,9,3),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmslatfr_el1",	CPENC (3,0,9,9,6),	0,		AARCH64_FEATURE (PROFILE))
  SYSREG ("pmsnevfr_el1",	CPENC (3,0,9,9,1),	0,		AARCH64_FEATURES (2, PROFILE, V8_6A)) /* SPE_FnE */
  SYSREG ("pmsscr_el1",		CPENC (3,0,9,13,3),	0,		AARCH64_FEATURE (V8_8A)) /* PMUv3_SS */
  SYSREG ("pmswinc_el0",	CPENC (3,3,9,12,4),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("pmuacr_el1",		CPENC (3,0,9,14,4),	0,		AARCH64_FEATURE (V8_8A)) /* PMUv3p9 */
  SYSREG ("pmuserenr_el0",	CPENC (3,3,9,14,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmxevcntr_el0",	CPENC (3,3,9,13,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmxevtyper_el0",	CPENC (3,3,9,13,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("pmzr_el0",		CPENC (3,3,9,13,4),	F_REG_WRITE,	AARCH64_FEATURE (V8_8A)) /* PMUv3p9 */
  SYSREG ("por_el0",		CPENC (3,3,10,2,4),	0,		AARCH64_FEATURE (V8_8A)) /* S1POE */
  SYSREG ("por_el1",		CPENC (3,0,10,2,4),	0,		AARCH64_FEATURE (V8_8A)) /* S1POE */
  SYSREG ("por_el12",		CPENC (3,5,10,2,4),	0,		AARCH64_FEATURE (V8_8A)) /* S1POE */
  SYSREG ("por_el2",		CPENC (3,4,10,2,4),	0,		AARCH64_FEATURE (V8_8A)) /* S1POE */
  SYSREG ("por_el3",		CPENC (3,6,10,2,4),	0,		AARCH64_FEATURE (V8_8A)) /* S1POE */
  SYSREG ("prbar10_el1",	CPENC (3,0,6,13,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar10_el2",	CPENC (3,4,6,13,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar11_el1",	CPENC (3,0,6,13,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar11_el2",	CPENC (3,4,6,13,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar12_el1",	CPENC (3,0,6,14,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar12_el2",	CPENC (3,4,6,14,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar13_el1",	CPENC (3,0,6,14,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar13_el2",	CPENC (3,4,6,14,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar14_el1",	CPENC (3,0,6,15,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar14_el2",	CPENC (3,4,6,15,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar15_el1",	CPENC (3,0,6,15,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar15_el2",	CPENC (3,4,6,15,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar1_el1",		CPENC (3,0,6,8,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar1_el2",		CPENC (3,4,6,8,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar2_el1",		CPENC (3,0,6,9,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar2_el2",		CPENC (3,4,6,9,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar3_el1",		CPENC (3,0,6,9,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar3_el2",		CPENC (3,4,6,9,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar4_el1",		CPENC (3,0,6,10,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar4_el2",		CPENC (3,4,6,10,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar5_el1",		CPENC (3,0,6,10,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar5_el2",		CPENC (3,4,6,10,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar6_el1",		CPENC (3,0,6,11,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar6_el2",		CPENC (3,4,6,11,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar7_el1",		CPENC (3,0,6,11,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar7_el2",		CPENC (3,4,6,11,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar8_el1",		CPENC (3,0,6,12,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar8_el2",		CPENC (3,4,6,12,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar9_el1",		CPENC (3,0,6,12,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar9_el2",		CPENC (3,4,6,12,4),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar_el1",		CPENC (3,0,6,8,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prbar_el2",		CPENC (3,4,6,8,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prenr_el1",		CPENC (3,0,6,1,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prenr_el2",		CPENC (3,4,6,1,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar10_el1",	CPENC (3,0,6,13,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar10_el2",	CPENC (3,4,6,13,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar11_el1",	CPENC (3,0,6,13,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar11_el2",	CPENC (3,4,6,13,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar12_el1",	CPENC (3,0,6,14,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar12_el2",	CPENC (3,4,6,14,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar13_el1",	CPENC (3,0,6,14,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar13_el2",	CPENC (3,4,6,14,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar14_el1",	CPENC (3,0,6,15,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar14_el2",	CPENC (3,4,6,15,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar15_el1",	CPENC (3,0,6,15,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar15_el2",	CPENC (3,4,6,15,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar1_el1",		CPENC (3,0,6,8,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar1_el2",		CPENC (3,4,6,8,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar2_el1",		CPENC (3,0,6,9,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar2_el2",		CPENC (3,4,6,9,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar3_el1",		CPENC (3,0,6,9,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar3_el2",		CPENC (3,4,6,9,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar4_el1",		CPENC (3,0,6,10,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar4_el2",		CPENC (3,4,6,10,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar5_el1",		CPENC (3,0,6,10,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar5_el2",		CPENC (3,4,6,10,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar6_el1",		CPENC (3,0,6,11,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar6_el2",		CPENC (3,4,6,11,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar7_el1",		CPENC (3,0,6,11,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar7_el2",		CPENC (3,4,6,11,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar8_el1",		CPENC (3,0,6,12,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar8_el2",		CPENC (3,4,6,12,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar9_el1",		CPENC (3,0,6,12,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar9_el2",		CPENC (3,4,6,12,5),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar_el1",		CPENC (3,0,6,8,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prlar_el2",		CPENC (3,4,6,8,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prselr_el1",		CPENC (3,0,6,2,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("prselr_el2",		CPENC (3,4,6,2,1),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("rcwmask_el1",	CPENC (3,0,13,0,6),	F_REG_128,	AARCH64_FEATURE (THE))
  SYSREG ("rcwsmask_el1",	CPENC (3,0,13,0,3),	F_REG_128,	AARCH64_FEATURE (THE))
  SYSREG ("revidr_el1",		CPENC (3,0,0,0,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("rgsr_el1",		CPENC (3,0,1,0,5),	0,		AARCH64_FEATURE (MEMTAG))
  SYSREG ("rmr_el1",		CPENC (3,0,12,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("rmr_el2",		CPENC (3,4,12,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("rmr_el3",		CPENC (3,6,12,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("rndr",		CPENC (3,3,2,4,0),	F_REG_READ,	AARCH64_FEATURE (RNG))
  SYSREG ("rndrrs",		CPENC (3,3,2,4,1),	F_REG_READ,	AARCH64_FEATURE (RNG))
  SYSREG ("rvbar_el1",		CPENC (3,0,12,0,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("rvbar_el2",		CPENC (3,4,12,0,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("rvbar_el3",		CPENC (3,6,12,0,1),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("s2pir_el2",		CPENC (3,4,10,2,5),	0,		AARCH64_FEATURE (V8_8A)) /* S2PIE */
  SYSREG ("s2por_el1",		CPENC (3,0,10,2,5),	0,		AARCH64_FEATURE (V8_8A)) /* S2POE */
  SYSREG ("scr_el3",		CPENC (3,6,1,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("scr2_el3",		CPENC (3,6,1,2,2),	0,		AARCH64_FEATURE (V9_3A)) /* SCR2 */
  SYSREG ("sctlr_el1",		CPENC (3,0,1,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("sctlr_el12",		CPENC (3,5,1,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("sctlr_el2",		CPENC (3,4,1,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("sctlr_el3",		CPENC (3,6,1,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("sctlr2_el1",		CPENC (3,0,1,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("sctlr2_el12",	CPENC (3,5,1,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("sctlr2_el2",		CPENC (3,4,1,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("sctlr2_el3",		CPENC (3,6,1,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("sctlr2alias_el1",	CPENC (3,0,1,4,7),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("sctlr2mask_el1",	CPENC (3,0,1,4,3),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("sctlr2mask_el12",	CPENC (3,5,1,4,3),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("sctlr2mask_el2",	CPENC (3,4,1,4,3),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("sctlralias_el1",	CPENC (3,0,1,4,6),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("sctlrmask_el1",	CPENC (3,0,1,4,0),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("sctlrmask_el12",	CPENC (3,5,1,4,0),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("sctlrmask_el2",	CPENC (3,4,1,4,0),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("scxtnum_el0",	CPENC (3,3,13,0,7),	0,		AARCH64_NO_FEATURES) /* CSV2_2 || CSV2_1p2 */
  SYSREG ("scxtnum_el1",	CPENC (3,0,13,0,7),	0,		AARCH64_NO_FEATURES) /* CSV2_2 || CSV2_1p2 */
  SYSREG ("scxtnum_el12",	CPENC (3,5,13,0,7),	0,		AARCH64_NO_FEATURES) /* CSV2_2 || CSV2_1p2 */
  SYSREG ("scxtnum_el2",	CPENC (3,4,13,0,7),	0,		AARCH64_NO_FEATURES) /* CSV2_2 || CSV2_1p2 */
  SYSREG ("scxtnum_el3",	CPENC (3,6,13,0,7),	0,		AARCH64_NO_FEATURES) /* CSV2_2 || CSV2_1p2 */
  SYSREG ("sder32_el2",		CPENC (3,4,1,3,1),	0,		AARCH64_FEATURE (V8_3A)) /* SEL2 */
  SYSREG ("sder32_el3",		CPENC (3,6,1,1,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("smcr_el1",		CPENC (3,0,1,2,6),	0,		AARCH64_FEATURE (SME))
  SYSREG ("smcr_el12",		CPENC (3,5,1,2,6),	0,		AARCH64_FEATURE (SME))
  SYSREG ("smcr_el2",		CPENC (3,4,1,2,6),	0,		AARCH64_FEATURE (SME))
  SYSREG ("smcr_el3",		CPENC (3,6,1,2,6),	0,		AARCH64_FEATURE (SME))
  SYSREG ("smidr_el1",		CPENC (3,1,0,0,6),	F_REG_READ,	AARCH64_FEATURE (SME))
  SYSREG ("smpri_el1",		CPENC (3,0,1,2,4),	0,		AARCH64_FEATURE (SME))
  SYSREG ("smprimap_el2",	CPENC (3,4,1,2,5),	0,		AARCH64_FEATURE (SME))
  SYSREG ("sp_el0",		CPENC (3,0,4,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("sp_el1",		CPENC (3,4,4,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("sp_el2",		CPENC (3,6,4,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("spmaccessr_el1",	CPENC (2,0,9,13,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmaccessr_el12",	CPENC (2,5,9,13,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmaccessr_el2",	CPENC (2,4,9,13,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmaccessr_el3",	CPENC (2,6,9,13,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmcfgr_el1",	CPENC (2,0,9,13,7),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmcgcr0_el1",	CPENC (2,0,9,13,0),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmcgcr1_el1",	CPENC (2,0,9,13,1),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmcntenclr_el0",	CPENC (2,3,9,12,2),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmcntenset_el0",	CPENC (2,3,9,12,1),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmcr_el0",		CPENC (2,3,9,12,0),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmdevaff_el1",	CPENC (2,0,9,13,6),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmdevarch_el1",	CPENC (2,0,9,13,5),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr0_el0",	CPENC (2,3,14,0,0),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr1_el0",	CPENC (2,3,14,0,1),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr2_el0",	CPENC (2,3,14,0,2),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr3_el0",	CPENC (2,3,14,0,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr4_el0",	CPENC (2,3,14,0,4),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr5_el0",	CPENC (2,3,14,0,5),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr6_el0",	CPENC (2,3,14,0,6),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr7_el0",	CPENC (2,3,14,0,7),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr8_el0",	CPENC (2,3,14,1,0),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr9_el0",	CPENC (2,3,14,1,1),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr10_el0",	CPENC (2,3,14,1,2),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr11_el0",	CPENC (2,3,14,1,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr12_el0",	CPENC (2,3,14,1,4),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr13_el0",	CPENC (2,3,14,1,5),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr14_el0",	CPENC (2,3,14,1,6),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevcntr15_el0",	CPENC (2,3,14,1,7),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r0_el0",	CPENC (2,3,14,6,0),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r1_el0",	CPENC (2,3,14,6,1),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r2_el0",	CPENC (2,3,14,6,2),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r3_el0",	CPENC (2,3,14,6,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r4_el0",	CPENC (2,3,14,6,4),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r5_el0",	CPENC (2,3,14,6,5),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r6_el0",	CPENC (2,3,14,6,6),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r7_el0",	CPENC (2,3,14,6,7),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r8_el0",	CPENC (2,3,14,7,0),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r9_el0",	CPENC (2,3,14,7,1),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r10_el0",	CPENC (2,3,14,7,2),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r11_el0",	CPENC (2,3,14,7,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r12_el0",	CPENC (2,3,14,7,4),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r13_el0",	CPENC (2,3,14,7,5),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r14_el0",	CPENC (2,3,14,7,6),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfilt2r15_el0",	CPENC (2,3,14,7,7),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr0_el0",	CPENC (2,3,14,4,0),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr1_el0",	CPENC (2,3,14,4,1),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr2_el0",	CPENC (2,3,14,4,2),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr3_el0",	CPENC (2,3,14,4,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr4_el0",	CPENC (2,3,14,4,4),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr5_el0",	CPENC (2,3,14,4,5),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr6_el0",	CPENC (2,3,14,4,6),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr7_el0",	CPENC (2,3,14,4,7),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr8_el0",	CPENC (2,3,14,5,0),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr9_el0",	CPENC (2,3,14,5,1),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr10_el0",	CPENC (2,3,14,5,2),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr11_el0",	CPENC (2,3,14,5,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr12_el0",	CPENC (2,3,14,5,4),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr13_el0",	CPENC (2,3,14,5,5),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr14_el0",	CPENC (2,3,14,5,6),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevfiltr15_el0",	CPENC (2,3,14,5,7),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper0_el0",	CPENC (2,3,14,2,0),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper1_el0",	CPENC (2,3,14,2,1),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper2_el0",	CPENC (2,3,14,2,2),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper3_el0",	CPENC (2,3,14,2,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper4_el0",	CPENC (2,3,14,2,4),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper5_el0",	CPENC (2,3,14,2,5),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper6_el0",	CPENC (2,3,14,2,6),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper7_el0",	CPENC (2,3,14,2,7),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper8_el0",	CPENC (2,3,14,3,0),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper9_el0",	CPENC (2,3,14,3,1),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper10_el0",	CPENC (2,3,14,3,2),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper11_el0",	CPENC (2,3,14,3,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper12_el0",	CPENC (2,3,14,3,4),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper13_el0",	CPENC (2,3,14,3,5),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper14_el0",	CPENC (2,3,14,3,6),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmevtyper15_el0",	CPENC (2,3,14,3,7),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmiidr_el1",	CPENC (2,0,9,13,4),	F_REG_READ,	AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmintenclr_el1",	CPENC (2,0,9,14,2),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmintenset_el1",	CPENC (2,0,9,14,1),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmovsclr_el0",	CPENC (2,3,9,12,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmovsset_el0",	CPENC (2,3,9,14,3),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmrootcr_el3",	CPENC (2,6,9,14,7),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmscr_el1",		CPENC (2,7,9,14,7),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmselr_el0",	CPENC (2,3,9,12,5),	0,		AARCH64_FEATURE (V8_8A)) /* SPMU */
  SYSREG ("spmzr_el0",		CPENC (2,3,9,12,4),	F_REG_WRITE,	AARCH64_FEATURE (V9_4A)) /* SPMU2 */
  SYSREG ("spsel",		CPENC (3,0,4,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("spsr_abt",		CPENC (3,4,4,3,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("spsr_el1",		CPENC (3,0,4,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("spsr_el12",		CPENC (3,5,4,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("spsr_el2",		CPENC (3,4,4,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("spsr_el3",		CPENC (3,6,4,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("spsr_fiq",		CPENC (3,4,4,3,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("spsr_hyp",		CPENC (3,4,4,0,0),	F_DEPRECATED,	AARCH64_NO_FEATURES)
  SYSREG ("spsr_irq",		CPENC (3,4,4,3,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("spsr_svc",		CPENC (3,0,4,0,0),	F_DEPRECATED,	AARCH64_NO_FEATURES)
  SYSREG ("spsr_und",		CPENC (3,4,4,3,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ssbs",		CPENC (3,3,4,2,6),	0,		AARCH64_FEATURE (SSBS))
  SYSREG ("stindex_el1",	CPENC (3,0,4,0,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("stindex_el12",	CPENC (3,5,4,0,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("stindex_el2",	CPENC (3,4,4,0,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("stindex_el3",	CPENC (3,6,4,0,2),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("svcr",		CPENC (3,3,4,2,2),	0,		AARCH64_FEATURE (SME))
  SYSREG ("tco",		CPENC (3,3,4,2,7),	0,		AARCH64_FEATURE (MEMTAG))
  SYSREG ("tcr_el1",		CPENC (3,0,2,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tcr_el12",		CPENC (3,5,2,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tcr_el2",		CPENC (3,4,2,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tcr_el3",		CPENC (3,6,2,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tcr2_el1",		CPENC (3,0,2,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tcr2_el12",		CPENC (3,5,2,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tcr2_el2",		CPENC (3,4,2,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tcr2alias_el1",	CPENC (3,0,2,7,7),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("tcr2mask_el1",	CPENC (3,0,2,7,3),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("tcr2mask_el12",	CPENC (3,5,2,7,3),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("tcr2mask_el2",	CPENC (3,4,2,7,3),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("tcralias_el1",	CPENC (3,0,2,7,6),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("tcrmask_el1",	CPENC (3,0,2,7,2),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("tcrmask_el12",	CPENC (3,5,2,7,2),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("tcrmask_el2",	CPENC (3,4,2,7,2),	0,		AARCH64_FEATURE (V9_5A)) /* SRMASK */
  SYSREG ("tfsr_el1",		CPENC (3,0,5,6,0),	0,		AARCH64_FEATURE (MEMTAG))
  SYSREG ("tfsr_el12",		CPENC (3,5,5,6,0),	0,		AARCH64_FEATURE (MEMTAG))
  SYSREG ("tfsr_el2",		CPENC (3,4,5,6,0),	0,		AARCH64_FEATURE (MEMTAG))
  SYSREG ("tfsr_el3",		CPENC (3,6,5,6,0),	0,		AARCH64_FEATURE (MEMTAG))
  SYSREG ("tfsre0_el1",		CPENC (3,0,5,6,1),	0,		AARCH64_FEATURE (MEMTAG))
  SYSREG ("tindex_el0",		CPENC (3,3,4,0,3),      0,		AARCH64_FEATURE (POE2))
  SYSREG ("tindex_el1",		CPENC (3,0,4,0,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tindex_el12",	CPENC (3,5,4,0,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tindex_el2",		CPENC (3,4,4,0,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tindex_el3",		CPENC (3,6,4,0,3),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tlbididr_el1",	CPENC (3,0,10,4,6),	F_REG_READ,	AARCH64_FEATURE (TLBID))
  SYSREG ("tpidr2_el0",		CPENC (3,3,13,0,5),	0,		AARCH64_FEATURE (SME))
  SYSREG ("tpidr3_el0",		CPENC (3,3,13,0,0),     0,		AARCH64_FEATURE (POE2))
  SYSREG ("tpidr3_el1",		CPENC (3,0,13,0,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tpidr3_el12",	CPENC (3,5,13,0,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tpidr3_el2",		CPENC (3,4,13,0,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tpidr3_el3",		CPENC (3,6,13,0,0),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tpidr_el0",		CPENC (3,3,13,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpidr_el1",		CPENC (3,0,13,0,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpidr_el2",		CPENC (3,4,13,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpidr_el3",		CPENC (3,6,13,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpidrro_el0",	CPENC (3,3,13,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmax0_el0",		CPENC (3,3,2,2,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmax0_el1",		CPENC (3,0,2,2,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmax0_el12",	CPENC (3,5,2,2,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmax0_el2",		CPENC (3,4,2,2,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmax1_el0",		CPENC (3,3,2,2,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmax1_el1",		CPENC (3,0,2,2,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmax1_el12",	CPENC (3,5,2,2,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmax1_el2",		CPENC (3,4,2,2,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmin0_el0",		CPENC (3,3,2,2,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmin0_el1",		CPENC (3,0,2,2,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmin0_el12",	CPENC (3,5,2,2,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmin0_el2",		CPENC (3,4,2,2,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmin1_el0",		CPENC (3,3,2,2,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmin1_el1",		CPENC (3,0,2,2,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmin1_el12",	CPENC (3,5,2,2,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("tpmin1_el2",		CPENC (3,4,2,2,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trbbaser_el1",	CPENC (3,0,9,11,2),	0,		AARCH64_FEATURE (V9A)) /* TRBE */
  SYSREG ("trbidr_el1",		CPENC (3,0,9,11,7),	F_REG_READ,	AARCH64_FEATURE (V9A)) /* TRBE */
  SYSREG ("trblimitr_el1",	CPENC (3,0,9,11,0),	0,		AARCH64_FEATURE (V9A)) /* TRBE */
  SYSREG ("trbmar_el1",		CPENC (3,0,9,11,4),	0,		AARCH64_FEATURE (V9A)) /* TRBE */
  SYSREG ("trbmpam_el1",	CPENC (3,0,9,11,5),	0,		AARCH64_FEATURE (V9_3A)) /* TRBE_MPAM */
  SYSREG ("trbptr_el1",		CPENC (3,0,9,11,1),	0,		AARCH64_FEATURE (V9A)) /* TRBE */
  SYSREG ("trbsr_el1",		CPENC (3,0,9,11,3),	0,		AARCH64_FEATURE (V9A)) /* TRBE */
  SYSREG ("trbsr_el12",		CPENC (3,5,9,11,3),	0,		AARCH64_FEATURE (V9_5A)) /* TRBE_EXC */
  SYSREG ("trbsr_el2",		CPENC (3,4,9,11,3),	0,		AARCH64_FEATURE (V9_5A)) /* TRBE_EXC */
  SYSREG ("trbsr_el3",		CPENC (3,6,9,11,3),	0,		AARCH64_FEATURE (V9_5A)) /* TRBE_EXC */
  SYSREG ("trbtrg_el1",		CPENC (3,0,9,11,6),	0,		AARCH64_FEATURE (V9A)) /* TRBE */
  SYSREG ("trcacatr0",		CPENC (2,1,2,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr1",		CPENC (2,1,2,2,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr10",		CPENC (2,1,2,4,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr11",		CPENC (2,1,2,6,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr12",		CPENC (2,1,2,8,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr13",		CPENC (2,1,2,10,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr14",		CPENC (2,1,2,12,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr15",		CPENC (2,1,2,14,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr2",		CPENC (2,1,2,4,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr3",		CPENC (2,1,2,6,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr4",		CPENC (2,1,2,8,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr5",		CPENC (2,1,2,10,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr6",		CPENC (2,1,2,12,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr7",		CPENC (2,1,2,14,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr8",		CPENC (2,1,2,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacatr9",		CPENC (2,1,2,2,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr0",		CPENC (2,1,2,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr1",		CPENC (2,1,2,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr10",		CPENC (2,1,2,4,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr11",		CPENC (2,1,2,6,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr12",		CPENC (2,1,2,8,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr13",		CPENC (2,1,2,10,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr14",		CPENC (2,1,2,12,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr15",		CPENC (2,1,2,14,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr2",		CPENC (2,1,2,4,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr3",		CPENC (2,1,2,6,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr4",		CPENC (2,1,2,8,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr5",		CPENC (2,1,2,10,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr6",		CPENC (2,1,2,12,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr7",		CPENC (2,1,2,14,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr8",		CPENC (2,1,2,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcacvr9",		CPENC (2,1,2,2,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcauthstatus",	CPENC (2,1,7,14,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcauxctlr",		CPENC (2,1,0,6,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcbbctlr",		CPENC (2,1,0,15,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcccctlr",		CPENC (2,1,0,14,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidcctlr0",	CPENC (2,1,3,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidcctlr1",	CPENC (2,1,3,1,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidcvr0",		CPENC (2,1,3,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidcvr1",		CPENC (2,1,3,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidcvr2",		CPENC (2,1,3,4,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidcvr3",		CPENC (2,1,3,6,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidcvr4",		CPENC (2,1,3,8,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidcvr5",		CPENC (2,1,3,10,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidcvr6",		CPENC (2,1,3,12,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidcvr7",		CPENC (2,1,3,14,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccidr0",		CPENC (2,1,7,12,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trccidr1",		CPENC (2,1,7,13,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trccidr2",		CPENC (2,1,7,14,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trccidr3",		CPENC (2,1,7,15,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcclaimclr",	CPENC (2,1,7,9,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcclaimset",	CPENC (2,1,7,8,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntctlr0",	CPENC (2,1,0,4,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntctlr1",	CPENC (2,1,0,5,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntctlr2",	CPENC (2,1,0,6,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntctlr3",	CPENC (2,1,0,7,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntrldvr0",	CPENC (2,1,0,0,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntrldvr1",	CPENC (2,1,0,1,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntrldvr2",	CPENC (2,1,0,2,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntrldvr3",	CPENC (2,1,0,3,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntvr0",		CPENC (2,1,0,8,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntvr1",		CPENC (2,1,0,9,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntvr2",		CPENC (2,1,0,10,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trccntvr3",		CPENC (2,1,0,11,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcconfigr",		CPENC (2,1,0,4,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdevaff0",		CPENC (2,1,7,10,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcdevaff1",		CPENC (2,1,7,11,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcdevarch",		CPENC (2,1,7,15,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcdevid",		CPENC (2,1,7,2,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcdevtype",		CPENC (2,1,7,3,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcdvcmr0",		CPENC (2,1,2,0,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcmr1",		CPENC (2,1,2,4,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcmr2",		CPENC (2,1,2,8,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcmr3",		CPENC (2,1,2,12,6),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcmr4",		CPENC (2,1,2,0,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcmr5",		CPENC (2,1,2,4,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcmr6",		CPENC (2,1,2,8,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcmr7",		CPENC (2,1,2,12,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcvr0",		CPENC (2,1,2,0,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcvr1",		CPENC (2,1,2,4,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcvr2",		CPENC (2,1,2,8,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcvr3",		CPENC (2,1,2,12,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcvr4",		CPENC (2,1,2,0,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcvr5",		CPENC (2,1,2,4,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcvr6",		CPENC (2,1,2,8,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcdvcvr7",		CPENC (2,1,2,12,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trceventctl0r",	CPENC (2,1,0,8,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trceventctl1r",	CPENC (2,1,0,9,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcextinselr",	CPENC (2,1,0,8,4),	F_REG_ALIAS,	AARCH64_NO_FEATURES)
  SYSREG ("trcextinselr0",	CPENC (2,1,0,8,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcextinselr1",	CPENC (2,1,0,9,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcextinselr2",	CPENC (2,1,0,10,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcextinselr3",	CPENC (2,1,0,11,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcidr0",		CPENC (2,1,0,8,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr1",		CPENC (2,1,0,9,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr10",		CPENC (2,1,0,2,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr11",		CPENC (2,1,0,3,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr12",		CPENC (2,1,0,4,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr13",		CPENC (2,1,0,5,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr2",		CPENC (2,1,0,10,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr3",		CPENC (2,1,0,11,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr4",		CPENC (2,1,0,12,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr5",		CPENC (2,1,0,13,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr6",		CPENC (2,1,0,14,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr7",		CPENC (2,1,0,15,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr8",		CPENC (2,1,0,0,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcidr9",		CPENC (2,1,0,1,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcimspec0",		CPENC (2,1,0,0,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcimspec1",		CPENC (2,1,0,1,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcimspec2",		CPENC (2,1,0,2,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcimspec3",		CPENC (2,1,0,3,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcimspec4",		CPENC (2,1,0,4,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcimspec5",		CPENC (2,1,0,5,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcimspec6",		CPENC (2,1,0,6,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcimspec7",		CPENC (2,1,0,7,7),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcitctrl",		CPENC (2,1,7,0,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcitecr_el1",	CPENC (3,0,1,2,3),	0,		AARCH64_FEATURE (ITE))
  SYSREG ("trcitecr_el12",	CPENC (3,5,1,2,3),	0,		AARCH64_FEATURE (ITE))
  SYSREG ("trcitecr_el2",	CPENC (3,4,1,2,3),	0,		AARCH64_FEATURE (ITE))
  SYSREG ("trciteedcr",		CPENC (2,1,0,2,1),	0,		AARCH64_FEATURE (ITE))
  SYSREG ("trclar",		CPENC (2,1,7,12,6),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("trclsr",		CPENC (2,1,7,13,6),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcoslar",		CPENC (2,1,1,0,4),	F_REG_WRITE,	AARCH64_NO_FEATURES)
  SYSREG ("trcoslsr",		CPENC (2,1,1,1,4),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcpdcr",		CPENC (2,1,1,4,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcpdsr",		CPENC (2,1,1,5,4),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcpidr0",		CPENC (2,1,7,8,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcpidr1",		CPENC (2,1,7,9,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcpidr2",		CPENC (2,1,7,10,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcpidr3",		CPENC (2,1,7,11,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcpidr4",		CPENC (2,1,7,4,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcpidr5",		CPENC (2,1,7,5,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcpidr6",		CPENC (2,1,7,6,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcpidr7",		CPENC (2,1,7,7,7),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcprgctlr",		CPENC (2,1,0,1,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcprocselr",	CPENC (2,1,0,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcqctlr",		CPENC (2,1,0,1,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr10",	CPENC (2,1,1,10,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr11",	CPENC (2,1,1,11,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr12",	CPENC (2,1,1,12,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr13",	CPENC (2,1,1,13,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr14",	CPENC (2,1,1,14,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr15",	CPENC (2,1,1,15,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr16",	CPENC (2,1,1,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr17",	CPENC (2,1,1,1,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr18",	CPENC (2,1,1,2,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr19",	CPENC (2,1,1,3,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr2",		CPENC (2,1,1,2,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr20",	CPENC (2,1,1,4,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr21",	CPENC (2,1,1,5,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr22",	CPENC (2,1,1,6,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr23",	CPENC (2,1,1,7,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr24",	CPENC (2,1,1,8,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr25",	CPENC (2,1,1,9,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr26",	CPENC (2,1,1,10,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr27",	CPENC (2,1,1,11,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr28",	CPENC (2,1,1,12,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr29",	CPENC (2,1,1,13,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr3",		CPENC (2,1,1,3,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr30",	CPENC (2,1,1,14,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr31",	CPENC (2,1,1,15,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr4",		CPENC (2,1,1,4,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr5",		CPENC (2,1,1,5,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr6",		CPENC (2,1,1,6,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr7",		CPENC (2,1,1,7,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr8",		CPENC (2,1,1,8,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsctlr9",		CPENC (2,1,1,9,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcrsr",		CPENC (2,1,0,10,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcseqevr0",		CPENC (2,1,0,0,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcseqevr1",		CPENC (2,1,0,1,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcseqevr2",		CPENC (2,1,0,2,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcseqrstevr",	CPENC (2,1,0,6,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcseqstr",		CPENC (2,1,0,7,4),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcssccr0",		CPENC (2,1,1,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcssccr1",		CPENC (2,1,1,1,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcssccr2",		CPENC (2,1,1,2,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcssccr3",		CPENC (2,1,1,3,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcssccr4",		CPENC (2,1,1,4,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcssccr5",		CPENC (2,1,1,5,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcssccr6",		CPENC (2,1,1,6,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcssccr7",		CPENC (2,1,1,7,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsscsr0",		CPENC (2,1,1,8,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsscsr1",		CPENC (2,1,1,9,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsscsr2",		CPENC (2,1,1,10,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsscsr3",		CPENC (2,1,1,11,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsscsr4",		CPENC (2,1,1,12,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsscsr5",		CPENC (2,1,1,13,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsscsr6",		CPENC (2,1,1,14,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsscsr7",		CPENC (2,1,1,15,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsspcicr0",	CPENC (2,1,1,0,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsspcicr1",	CPENC (2,1,1,1,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsspcicr2",	CPENC (2,1,1,2,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsspcicr3",	CPENC (2,1,1,3,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsspcicr4",	CPENC (2,1,1,4,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsspcicr5",	CPENC (2,1,1,5,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsspcicr6",	CPENC (2,1,1,6,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcsspcicr7",	CPENC (2,1,1,7,3),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcstallctlr",	CPENC (2,1,0,11,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcstatr",		CPENC (2,1,0,3,0),	F_REG_READ,	AARCH64_NO_FEATURES)
  SYSREG ("trcsyncpr",		CPENC (2,1,0,13,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trctraceidr",	CPENC (2,1,0,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trctsctlr",		CPENC (2,1,0,12,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvdarcctlr",	CPENC (2,1,0,10,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvdctlr",		CPENC (2,1,0,8,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvdsacctlr",	CPENC (2,1,0,9,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvictlr",		CPENC (2,1,0,0,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcviiectlr",	CPENC (2,1,0,1,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvipcssctlr",	CPENC (2,1,0,3,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvissctlr",	CPENC (2,1,0,2,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvmidcctlr0",	CPENC (2,1,3,2,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvmidcctlr1",	CPENC (2,1,3,3,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvmidcvr0",	CPENC (2,1,3,0,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvmidcvr1",	CPENC (2,1,3,2,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvmidcvr2",	CPENC (2,1,3,4,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvmidcvr3",	CPENC (2,1,3,6,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvmidcvr4",	CPENC (2,1,3,8,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvmidcvr5",	CPENC (2,1,3,10,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvmidcvr6",	CPENC (2,1,3,12,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trcvmidcvr7",	CPENC (2,1,3,14,1),	0,		AARCH64_NO_FEATURES)
  SYSREG ("trfcr_el1",		CPENC (3,0,1,2,1),	0,		AARCH64_FEATURE (V8_3A)) /* TRF */
  SYSREG ("trfcr_el12",		CPENC (3,5,1,2,1),	0,		AARCH64_FEATURE (V8_3A)) /* TRF */
  SYSREG ("trfcr_el2",		CPENC (3,4,1,2,1),	0,		AARCH64_FEATURE (V8_3A)) /* TRF */
  SYSREG ("ttbr0_el1",		CPENC (3,0,2,0,0),	F_REG_128,	AARCH64_NO_FEATURES)
  SYSREG ("ttbr0_el12",		CPENC (3,5,2,0,0),	F_REG_128,	AARCH64_NO_FEATURES)
  SYSREG ("ttbr0_el2",		CPENC (3,4,2,0,0),	F_REG_128,	AARCH64_FEATURE (V8A))
  SYSREG ("ttbr0_el3",		CPENC (3,6,2,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("ttbr1_el1",		CPENC (3,0,2,0,1),	F_REG_128,	AARCH64_NO_FEATURES)
  SYSREG ("ttbr1_el12",		CPENC (3,5,2,0,1),	F_REG_128,	AARCH64_NO_FEATURES)
  SYSREG ("ttbr1_el2",		CPENC (3,4,2,0,1),	F_REG_128,	AARCH64_FEATURE (V8A))
  SYSREG ("tttbrp_el1",		CPENC (3,0,10,2,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tttbrp_el12",	CPENC (3,5,10,2,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tttbrp_el2",		CPENC (3,4,10,2,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tttbrp_el3",		CPENC (3,6,10,2,7),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tttbru_el1",		CPENC (3,0,10,2,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tttbru_el12",	CPENC (3,5,10,2,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("tttbru_el2",		CPENC (3,4,10,2,6),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("uao",		CPENC (3,0,4,2,4),	0,		AARCH64_FEATURE (V8_1A)) /* UAO */
  SYSREG ("vbar_el1",		CPENC (3,0,12,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("vbar_el12",		CPENC (3,5,12,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("vbar_el2",		CPENC (3,4,12,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("vbar_el3",		CPENC (3,6,12,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("vdisr_el2",		CPENC (3,4,12,1,1),	0,		AARCH64_FEATURE (RAS))
  SYSREG ("vdisr_el3",		CPENC (3,6,12,1,1),	0,		AARCH64_FEATURE (V9_4A)) /* E3DSE */
  SYSREG ("vmecid_a_el2",	CPENC (3,4,10,9,1),	0,		AARCH64_FEATURE (V9_2A)) /* MEC */
  SYSREG ("vmecid_p_el2",	CPENC (3,4,10,9,0),	0,		AARCH64_FEATURE (V9_2A)) /* MEC */
  SYSREG ("vmpidr_el2",		CPENC (3,4,0,0,5),	0,		AARCH64_NO_FEATURES)
  SYSREG ("vnccr_el2",		CPENC (3,4,2,2,1),	0,		AARCH64_FEATURE (POE2))
  SYSREG ("vncr_el2",		CPENC (3,4,2,2,0),	0,		AARCH64_FEATURE (V8_3A)) /* NV2 */
  SYSREG ("vpidr_el2",		CPENC (3,4,0,0,0),	0,		AARCH64_NO_FEATURES)
  SYSREG ("vsctlr_el2",		CPENC (3,4,2,0,0),	0,		AARCH64_FEATURE (V8R))
  SYSREG ("vsesr_el2",		CPENC (3,4,5,2,3),	0,		AARCH64_FEATURE (RAS))
  SYSREG ("vsesr_el3",		CPENC (3,6,5,2,3),	0,		AARCH64_FEATURE (V9_4A)) /* E3DSE */
  SYSREG ("vstcr_el2",		CPENC (3,4,2,6,2),	0,		AARCH64_FEATURE (V8_3A)) /* SEL2 */
  SYSREG ("vsttbr_el2",		CPENC (3,4,2,6,0),	0,		AARCH64_FEATURES (2, V8A, V8_3A)) /* SEL2 */
  SYSREG ("vtcr_el2",		CPENC (3,4,2,1,2),	0,		AARCH64_NO_FEATURES)
  SYSREG ("vtlbid0_el2",	CPENC (3,4,2,8,0),	0,		AARCH64_FEATURE (TLBID))
  SYSREG ("vtlbid1_el2",	CPENC (3,4,2,8,1),	0,		AARCH64_FEATURE (TLBID))
  SYSREG ("vtlbid2_el2",	CPENC (3,4,2,8,2),	0,		AARCH64_FEATURE (TLBID))
  SYSREG ("vtlbid3_el2",	CPENC (3,4,2,8,3),	0,		AARCH64_FEATURE (TLBID))
  SYSREG ("vtlbidos0_el2",	CPENC (3,4,2,9,0),	0,		AARCH64_FEATURE (TLBID))
  SYSREG ("vtlbidos1_el2",	CPENC (3,4,2,9,1),	0,		AARCH64_FEATURE (TLBID))
  SYSREG ("vtlbidos2_el2",	CPENC (3,4,2,9,2),	0,		AARCH64_FEATURE (TLBID))
  SYSREG ("vtlbidos3_el2",	CPENC (3,4,2,9,3),	0,		AARCH64_FEATURE (TLBID))
  SYSREG ("vttbr_el2",		CPENC (3,4,2,1,0),	F_REG_128,	AARCH64_FEATURE (V8A))
  SYSREG ("zcr_el1",		CPENC (3,0,1,2,0),	0,		AARCH64_FEATURE (SVE))
  SYSREG ("zcr_el12",		CPENC (3,5,1,2,0),	0,		AARCH64_FEATURE (SVE))
  SYSREG ("zcr_el2",		CPENC (3,4,1,2,0),	0,		AARCH64_FEATURE (SVE))
  SYSREG ("zcr_el3",		CPENC (3,6,1,2,0),	0,		AARCH64_FEATURE (SVE))
